@@ -6,7 +6,7 @@ use uuid::Uuid;
 
 
 
-/// Describes an audio file. Audio is usually in MP3 or M4A format
+/// Describes an audio file. Audio is usually in MP3 format
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct Audio {
   #[doc(hidden)]
@@ -25,10 +25,8 @@ pub struct Audio {
   file_name: String,
   /// The MIME type of the file; as defined by the sender
   mime_type: String,
-  /// The minithumbnail of the album cover; may be null
-  album_cover_minithumbnail: Option<Minithumbnail>,
-  /// The thumbnail of the album cover in JPEG format; as defined by the sender. The full size thumbnail is supposed to be extracted from the downloaded file; may be null
-  album_cover_thumbnail: Option<Thumbnail>,
+  /// The thumbnail of the album cover; as defined by the sender. The full size thumbnail should be extracted from the downloaded file; may be null
+  album_cover_thumbnail: Option<PhotoSize>,
   /// File containing the audio
   audio: File,
   
@@ -61,9 +59,7 @@ impl Audio {
 
   pub fn mime_type(&self) -> &String { &self.mime_type }
 
-  pub fn album_cover_minithumbnail(&self) -> &Option<Minithumbnail> { &self.album_cover_minithumbnail }
-
-  pub fn album_cover_thumbnail(&self) -> &Option<Thumbnail> { &self.album_cover_thumbnail }
+  pub fn album_cover_thumbnail(&self) -> &Option<PhotoSize> { &self.album_cover_thumbnail }
 
   pub fn audio(&self) -> &File { &self.audio }
 
@@ -108,13 +104,7 @@ impl RTDAudioBuilder {
   }
 
    
-  pub fn album_cover_minithumbnail<T: AsRef<Minithumbnail>>(&mut self, album_cover_minithumbnail: T) -> &mut Self {
-    self.inner.album_cover_minithumbnail = Some(album_cover_minithumbnail.as_ref().clone());
-    self
-  }
-
-   
-  pub fn album_cover_thumbnail<T: AsRef<Thumbnail>>(&mut self, album_cover_thumbnail: T) -> &mut Self {
+  pub fn album_cover_thumbnail<T: AsRef<PhotoSize>>(&mut self, album_cover_thumbnail: T) -> &mut Self {
     self.inner.album_cover_thumbnail = Some(album_cover_thumbnail.as_ref().clone());
     self
   }
