@@ -11,15 +11,15 @@ use serde::de::{Deserialize, Deserializer};
 
 
 
-/// TRAIT | Represents the current authorization state of the TDLib client
+/// TRAIT | Represents the current authorization state of the client
 pub trait TDAuthorizationState: Debug + RObject {}
 
-/// Represents the current authorization state of the TDLib client
+/// Represents the current authorization state of the client
 #[derive(Debug, Clone, Serialize)]
 #[serde(untagged)]
 pub enum AuthorizationState {
   #[doc(hidden)] _Default(()),
-  /// TDLib client is in its final state. All databases are closed and all resources are released. No other updates will be received after this. All queries will be responded to with error code 500. To continue working, one must create a new instance of the TDLib client
+  /// TDLib client is in its final state. All databases are closed and all resources are released. No other updates will be received after this. All queries will be responded to with error code 500. To continue working, one should create a new instance of the TDLib client
   Closed(AuthorizationStateClosed),
   /// TDLib is closing, all subsequent queries will be answered with the error 500. Note that closing TDLib can take a while. All resources will be freed only after authorizationStateClosed has been received
   Closing(AuthorizationStateClosing),
@@ -27,21 +27,17 @@ pub enum AuthorizationState {
   LoggingOut(AuthorizationStateLoggingOut),
   /// The user has been successfully authorized. TDLib is now ready to answer queries
   Ready(AuthorizationStateReady),
-  /// TDLib needs the user's authentication code to authorize
+  /// TDLib needs the user's authentication code to finalize authorization
   WaitCode(AuthorizationStateWaitCode),
   /// TDLib needs an encryption key to decrypt the local database
   WaitEncryptionKey(AuthorizationStateWaitEncryptionKey),
-  /// The user needs to confirm authorization on another logged in device by scanning a QR code with the provided link
-  WaitOtherDeviceConfirmation(AuthorizationStateWaitOtherDeviceConfirmation),
   /// The user has been authorized, but needs to enter a password to start using the application
   WaitPassword(AuthorizationStateWaitPassword),
-  /// TDLib needs the user's phone number to authorize. Call `setAuthenticationPhoneNumber` to provide the phone number, or use `requestQrCodeAuthentication`, or `checkAuthenticationBotToken` for other authentication options
+  /// TDLib needs the user's phone number to authorize
   WaitPhoneNumber(AuthorizationStateWaitPhoneNumber),
-  /// The user is unregistered and need to accept terms of service and enter their first name and last name to finish registration
-  WaitRegistration(AuthorizationStateWaitRegistration),
   /// TDLib needs TdlibParameters for initialization
   WaitTdlibParameters(AuthorizationStateWaitTdlibParameters),
-  /// Returns the current authorization state; this is an offline request. For informational purposes only. Use updateAuthorizationState instead to maintain the current authorization state. Can be called before initialization
+  /// Returns the current authorization state; this is an offline request. For informational purposes only. Use updateAuthorizationState instead to maintain the current authorization state
   GetAuthorizationState(GetAuthorizationState),
 
 }
@@ -61,10 +57,8 @@ impl<'de> Deserialize<'de> for AuthorizationState {
       (authorizationStateReady, Ready);
       (authorizationStateWaitCode, WaitCode);
       (authorizationStateWaitEncryptionKey, WaitEncryptionKey);
-      (authorizationStateWaitOtherDeviceConfirmation, WaitOtherDeviceConfirmation);
       (authorizationStateWaitPassword, WaitPassword);
       (authorizationStateWaitPhoneNumber, WaitPhoneNumber);
-      (authorizationStateWaitRegistration, WaitRegistration);
       (authorizationStateWaitTdlibParameters, WaitTdlibParameters);
       (getAuthorizationState, GetAuthorizationState);
 
@@ -81,10 +75,8 @@ impl RObject for AuthorizationState {
       AuthorizationState::Ready(t) => t.td_name(),
       AuthorizationState::WaitCode(t) => t.td_name(),
       AuthorizationState::WaitEncryptionKey(t) => t.td_name(),
-      AuthorizationState::WaitOtherDeviceConfirmation(t) => t.td_name(),
       AuthorizationState::WaitPassword(t) => t.td_name(),
       AuthorizationState::WaitPhoneNumber(t) => t.td_name(),
-      AuthorizationState::WaitRegistration(t) => t.td_name(),
       AuthorizationState::WaitTdlibParameters(t) => t.td_name(),
       AuthorizationState::GetAuthorizationState(t) => t.td_name(),
 
@@ -99,10 +91,8 @@ impl RObject for AuthorizationState {
       AuthorizationState::Ready(t) => t.extra(),
       AuthorizationState::WaitCode(t) => t.extra(),
       AuthorizationState::WaitEncryptionKey(t) => t.extra(),
-      AuthorizationState::WaitOtherDeviceConfirmation(t) => t.extra(),
       AuthorizationState::WaitPassword(t) => t.extra(),
       AuthorizationState::WaitPhoneNumber(t) => t.extra(),
-      AuthorizationState::WaitRegistration(t) => t.extra(),
       AuthorizationState::WaitTdlibParameters(t) => t.extra(),
       AuthorizationState::GetAuthorizationState(t) => t.extra(),
 
@@ -122,10 +112,8 @@ impl AuthorizationState {
   pub fn is_ready(&self) -> bool { if let AuthorizationState::Ready(_) = self { true } else { false } }
   pub fn is_wait_code(&self) -> bool { if let AuthorizationState::WaitCode(_) = self { true } else { false } }
   pub fn is_wait_encryption_key(&self) -> bool { if let AuthorizationState::WaitEncryptionKey(_) = self { true } else { false } }
-  pub fn is_wait_other_device_confirmation(&self) -> bool { if let AuthorizationState::WaitOtherDeviceConfirmation(_) = self { true } else { false } }
   pub fn is_wait_password(&self) -> bool { if let AuthorizationState::WaitPassword(_) = self { true } else { false } }
   pub fn is_wait_phone_number(&self) -> bool { if let AuthorizationState::WaitPhoneNumber(_) = self { true } else { false } }
-  pub fn is_wait_registration(&self) -> bool { if let AuthorizationState::WaitRegistration(_) = self { true } else { false } }
   pub fn is_wait_tdlib_parameters(&self) -> bool { if let AuthorizationState::WaitTdlibParameters(_) = self { true } else { false } }
   pub fn is_get_authorization_state(&self) -> bool { if let AuthorizationState::GetAuthorizationState(_) = self { true } else { false } }
 
@@ -135,10 +123,8 @@ impl AuthorizationState {
   pub fn on_ready<F: FnOnce(&AuthorizationStateReady)>(&self, fnc: F) -> &Self { if let AuthorizationState::Ready(t) = self { fnc(t) }; self }
   pub fn on_wait_code<F: FnOnce(&AuthorizationStateWaitCode)>(&self, fnc: F) -> &Self { if let AuthorizationState::WaitCode(t) = self { fnc(t) }; self }
   pub fn on_wait_encryption_key<F: FnOnce(&AuthorizationStateWaitEncryptionKey)>(&self, fnc: F) -> &Self { if let AuthorizationState::WaitEncryptionKey(t) = self { fnc(t) }; self }
-  pub fn on_wait_other_device_confirmation<F: FnOnce(&AuthorizationStateWaitOtherDeviceConfirmation)>(&self, fnc: F) -> &Self { if let AuthorizationState::WaitOtherDeviceConfirmation(t) = self { fnc(t) }; self }
   pub fn on_wait_password<F: FnOnce(&AuthorizationStateWaitPassword)>(&self, fnc: F) -> &Self { if let AuthorizationState::WaitPassword(t) = self { fnc(t) }; self }
   pub fn on_wait_phone_number<F: FnOnce(&AuthorizationStateWaitPhoneNumber)>(&self, fnc: F) -> &Self { if let AuthorizationState::WaitPhoneNumber(t) = self { fnc(t) }; self }
-  pub fn on_wait_registration<F: FnOnce(&AuthorizationStateWaitRegistration)>(&self, fnc: F) -> &Self { if let AuthorizationState::WaitRegistration(t) = self { fnc(t) }; self }
   pub fn on_wait_tdlib_parameters<F: FnOnce(&AuthorizationStateWaitTdlibParameters)>(&self, fnc: F) -> &Self { if let AuthorizationState::WaitTdlibParameters(t) = self { fnc(t) }; self }
   pub fn on_get_authorization_state<F: FnOnce(&GetAuthorizationState)>(&self, fnc: F) -> &Self { if let AuthorizationState::GetAuthorizationState(t) = self { fnc(t) }; self }
 
@@ -148,10 +134,8 @@ impl AuthorizationState {
   pub fn as_ready(&self) -> Option<&AuthorizationStateReady> { if let AuthorizationState::Ready(t) = self { return Some(t) } None }
   pub fn as_wait_code(&self) -> Option<&AuthorizationStateWaitCode> { if let AuthorizationState::WaitCode(t) = self { return Some(t) } None }
   pub fn as_wait_encryption_key(&self) -> Option<&AuthorizationStateWaitEncryptionKey> { if let AuthorizationState::WaitEncryptionKey(t) = self { return Some(t) } None }
-  pub fn as_wait_other_device_confirmation(&self) -> Option<&AuthorizationStateWaitOtherDeviceConfirmation> { if let AuthorizationState::WaitOtherDeviceConfirmation(t) = self { return Some(t) } None }
   pub fn as_wait_password(&self) -> Option<&AuthorizationStateWaitPassword> { if let AuthorizationState::WaitPassword(t) = self { return Some(t) } None }
   pub fn as_wait_phone_number(&self) -> Option<&AuthorizationStateWaitPhoneNumber> { if let AuthorizationState::WaitPhoneNumber(t) = self { return Some(t) } None }
-  pub fn as_wait_registration(&self) -> Option<&AuthorizationStateWaitRegistration> { if let AuthorizationState::WaitRegistration(t) = self { return Some(t) } None }
   pub fn as_wait_tdlib_parameters(&self) -> Option<&AuthorizationStateWaitTdlibParameters> { if let AuthorizationState::WaitTdlibParameters(t) = self { return Some(t) } None }
   pub fn as_get_authorization_state(&self) -> Option<&GetAuthorizationState> { if let AuthorizationState::GetAuthorizationState(t) = self { return Some(t) } None }
 
@@ -169,14 +153,10 @@ impl AuthorizationState {
 
   pub fn wait_encryption_key<T: AsRef<AuthorizationStateWaitEncryptionKey>>(t: T) -> Self { AuthorizationState::WaitEncryptionKey(t.as_ref().clone()) }
 
-  pub fn wait_other_device_confirmation<T: AsRef<AuthorizationStateWaitOtherDeviceConfirmation>>(t: T) -> Self { AuthorizationState::WaitOtherDeviceConfirmation(t.as_ref().clone()) }
-
   pub fn wait_password<T: AsRef<AuthorizationStateWaitPassword>>(t: T) -> Self { AuthorizationState::WaitPassword(t.as_ref().clone()) }
 
   pub fn wait_phone_number<T: AsRef<AuthorizationStateWaitPhoneNumber>>(t: T) -> Self { AuthorizationState::WaitPhoneNumber(t.as_ref().clone()) }
 
-  pub fn wait_registration<T: AsRef<AuthorizationStateWaitRegistration>>(t: T) -> Self { AuthorizationState::WaitRegistration(t.as_ref().clone()) }
-
   pub fn wait_tdlib_parameters<T: AsRef<AuthorizationStateWaitTdlibParameters>>(t: T) -> Self { AuthorizationState::WaitTdlibParameters(t.as_ref().clone()) }
 
   pub fn get_authorization_state<T: AsRef<GetAuthorizationState>>(t: T) -> Self { AuthorizationState::GetAuthorizationState(t.as_ref().clone()) }
@@ -193,7 +173,7 @@ impl AsRef<AuthorizationState> for AuthorizationState {
 
 
 
-/// TDLib client is in its final state. All databases are closed and all resources are released. No other updates will be received after this. All queries will be responded to with error code 500. To continue working, one must create a new instance of the TDLib client
+/// TDLib client is in its final state. All databases are closed and all resources are released. No other updates will be received after this. All queries will be responded to with error code 500. To continue working, one should create a new instance of the TDLib client
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct AuthorizationStateClosed {
   #[doc(hidden)]
@@ -425,7 +405,7 @@ impl AsRef<AuthorizationStateReady> for RTDAuthorizationStateReadyBuilder {
 
 
 
-/// TDLib needs the user's authentication code to authorize
+/// TDLib needs the user's authentication code to finalize authorization
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct AuthorizationStateWaitCode {
   #[doc(hidden)]
@@ -434,6 +414,10 @@ pub struct AuthorizationStateWaitCode {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
+  /// True, if the user is already registered
+  is_registered: bool,
+  /// Telegram terms of service, which should be accepted before user can continue registration; may be null
+  terms_of_service: Option<TermsOfService>,
   /// Information about the authorization code that was sent
   code_info: AuthenticationCodeInfo,
   
@@ -459,6 +443,10 @@ impl AuthorizationStateWaitCode {
     RTDAuthorizationStateWaitCodeBuilder { inner }
   }
 
+  pub fn is_registered(&self) -> bool { self.is_registered }
+
+  pub fn terms_of_service(&self) -> &Option<TermsOfService> { &self.terms_of_service }
+
   pub fn code_info(&self) -> &AuthenticationCodeInfo { &self.code_info }
 
 }
@@ -472,6 +460,18 @@ impl RTDAuthorizationStateWaitCodeBuilder {
   pub fn build(&self) -> AuthorizationStateWaitCode { self.inner.clone() }
 
    
+  pub fn is_registered(&mut self, is_registered: bool) -> &mut Self {
+    self.inner.is_registered = is_registered;
+    self
+  }
+
+   
+  pub fn terms_of_service<T: AsRef<TermsOfService>>(&mut self, terms_of_service: T) -> &mut Self {
+    self.inner.terms_of_service = Some(terms_of_service.as_ref().clone());
+    self
+  }
+
+   
   pub fn code_info<T: AsRef<AuthenticationCodeInfo>>(&mut self, code_info: T) -> &mut Self {
     self.inner.code_info = code_info.as_ref().clone();
     self
@@ -561,74 +561,6 @@ impl AsRef<AuthorizationStateWaitEncryptionKey> for RTDAuthorizationStateWaitEnc
 
 
 
-/// The user needs to confirm authorization on another logged in device by scanning a QR code with the provided link
-#[derive(Debug, Clone, Default, Serialize, Deserialize)]
-pub struct AuthorizationStateWaitOtherDeviceConfirmation {
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@type", deserialize = "@type"))]
-  td_name: String,
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
-  extra: Option<String>,
-  /// A tg:// URL for the QR code. The link will be updated frequently
-  link: String,
-  
-}
-
-impl RObject for AuthorizationStateWaitOtherDeviceConfirmation {
-  #[doc(hidden)] fn td_name(&self) -> &'static str { "authorizationStateWaitOtherDeviceConfirmation" }
-  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
-  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
-}
-
-
-impl TDAuthorizationState for AuthorizationStateWaitOtherDeviceConfirmation {}
-
-
-
-impl AuthorizationStateWaitOtherDeviceConfirmation {
-  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
-  pub fn builder() -> RTDAuthorizationStateWaitOtherDeviceConfirmationBuilder {
-    let mut inner = AuthorizationStateWaitOtherDeviceConfirmation::default();
-    inner.td_name = "authorizationStateWaitOtherDeviceConfirmation".to_string();
-    inner.extra = Some(Uuid::new_v4().to_string());
-    RTDAuthorizationStateWaitOtherDeviceConfirmationBuilder { inner }
-  }
-
-  pub fn link(&self) -> &String { &self.link }
-
-}
-
-#[doc(hidden)]
-pub struct RTDAuthorizationStateWaitOtherDeviceConfirmationBuilder {
-  inner: AuthorizationStateWaitOtherDeviceConfirmation
-}
-
-impl RTDAuthorizationStateWaitOtherDeviceConfirmationBuilder {
-  pub fn build(&self) -> AuthorizationStateWaitOtherDeviceConfirmation { self.inner.clone() }
-
-   
-  pub fn link<T: AsRef<str>>(&mut self, link: T) -> &mut Self {
-    self.inner.link = link.as_ref().to_string();
-    self
-  }
-
-}
-
-impl AsRef<AuthorizationStateWaitOtherDeviceConfirmation> for AuthorizationStateWaitOtherDeviceConfirmation {
-  fn as_ref(&self) -> &AuthorizationStateWaitOtherDeviceConfirmation { self }
-}
-
-impl AsRef<AuthorizationStateWaitOtherDeviceConfirmation> for RTDAuthorizationStateWaitOtherDeviceConfirmationBuilder {
-  fn as_ref(&self) -> &AuthorizationStateWaitOtherDeviceConfirmation { &self.inner }
-}
-
-
-
-
-
-
-
 /// The user has been authorized, but needs to enter a password to start using the application
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct AuthorizationStateWaitPassword {
@@ -638,9 +570,9 @@ pub struct AuthorizationStateWaitPassword {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// Hint for the password; may be empty
+  /// Hint for the password; can be empty
   password_hint: String,
-  /// True, if a recovery email address has been set up
+  /// True if a recovery email address has been set up
   has_recovery_email_address: bool,
   /// Pattern of the email address to which the recovery email was sent; empty until a recovery email has been sent
   recovery_email_address_pattern: String,
@@ -717,7 +649,7 @@ impl AsRef<AuthorizationStateWaitPassword> for RTDAuthorizationStateWaitPassword
 
 
 
-/// TDLib needs the user's phone number to authorize. Call `setAuthenticationPhoneNumber` to provide the phone number, or use `requestQrCodeAuthentication`, or `checkAuthenticationBotToken` for other authentication options
+/// TDLib needs the user's phone number to authorize
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct AuthorizationStateWaitPhoneNumber {
   #[doc(hidden)]
@@ -775,74 +707,6 @@ impl AsRef<AuthorizationStateWaitPhoneNumber> for RTDAuthorizationStateWaitPhone
 
 
 
-/// The user is unregistered and need to accept terms of service and enter their first name and last name to finish registration
-#[derive(Debug, Clone, Default, Serialize, Deserialize)]
-pub struct AuthorizationStateWaitRegistration {
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@type", deserialize = "@type"))]
-  td_name: String,
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
-  extra: Option<String>,
-  /// Telegram terms of service
-  terms_of_service: TermsOfService,
-  
-}
-
-impl RObject for AuthorizationStateWaitRegistration {
-  #[doc(hidden)] fn td_name(&self) -> &'static str { "authorizationStateWaitRegistration" }
-  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
-  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
-}
-
-
-impl TDAuthorizationState for AuthorizationStateWaitRegistration {}
-
-
-
-impl AuthorizationStateWaitRegistration {
-  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
-  pub fn builder() -> RTDAuthorizationStateWaitRegistrationBuilder {
-    let mut inner = AuthorizationStateWaitRegistration::default();
-    inner.td_name = "authorizationStateWaitRegistration".to_string();
-    inner.extra = Some(Uuid::new_v4().to_string());
-    RTDAuthorizationStateWaitRegistrationBuilder { inner }
-  }
-
-  pub fn terms_of_service(&self) -> &TermsOfService { &self.terms_of_service }
-
-}
-
-#[doc(hidden)]
-pub struct RTDAuthorizationStateWaitRegistrationBuilder {
-  inner: AuthorizationStateWaitRegistration
-}
-
-impl RTDAuthorizationStateWaitRegistrationBuilder {
-  pub fn build(&self) -> AuthorizationStateWaitRegistration { self.inner.clone() }
-
-   
-  pub fn terms_of_service<T: AsRef<TermsOfService>>(&mut self, terms_of_service: T) -> &mut Self {
-    self.inner.terms_of_service = terms_of_service.as_ref().clone();
-    self
-  }
-
-}
-
-impl AsRef<AuthorizationStateWaitRegistration> for AuthorizationStateWaitRegistration {
-  fn as_ref(&self) -> &AuthorizationStateWaitRegistration { self }
-}
-
-impl AsRef<AuthorizationStateWaitRegistration> for RTDAuthorizationStateWaitRegistrationBuilder {
-  fn as_ref(&self) -> &AuthorizationStateWaitRegistration { &self.inner }
-}
-
-
-
-
-
-
-
 /// TDLib needs TdlibParameters for initialization
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct AuthorizationStateWaitTdlibParameters {
