@@ -144,9 +144,9 @@ pub struct CallStateDiscarded {
   extra: Option<String>,
   /// The reason, why the call has ended
   reason: CallDiscardReason,
-  /// True, if the call rating must be sent to the server
+  /// True, if the call rating should be sent to the server
   need_rating: bool,
-  /// True, if the call debug information must be sent to the server
+  /// True, if the call debug information should be sent to the server
   need_debug_information: bool,
   
 }
@@ -494,16 +494,14 @@ pub struct CallStateReady {
   extra: Option<String>,
   /// Call protocols supported by the peer
   protocol: CallProtocol,
-  /// List of available call servers
-  servers: Vec<CallServer>,
+  /// Available UDP reflectors
+  connections: Vec<CallConnection>,
   /// A JSON-encoded call config
   config: String,
   /// Call encryption key
   encryption_key: String,
   /// Encryption key emojis fingerprint
   emojis: Vec<String>,
-  /// True, if peer-to-peer connection is allowed by users privacy settings
-  allow_p2p: bool,
   
 }
 
@@ -529,7 +527,7 @@ impl CallStateReady {
 
   pub fn protocol(&self) -> &CallProtocol { &self.protocol }
 
-  pub fn servers(&self) -> &Vec<CallServer> { &self.servers }
+  pub fn connections(&self) -> &Vec<CallConnection> { &self.connections }
 
   pub fn config(&self) -> &String { &self.config }
 
@@ -537,8 +535,6 @@ impl CallStateReady {
 
   pub fn emojis(&self) -> &Vec<String> { &self.emojis }
 
-  pub fn allow_p2p(&self) -> bool { self.allow_p2p }
-
 }
 
 #[doc(hidden)]
@@ -556,8 +552,8 @@ impl RTDCallStateReadyBuilder {
   }
 
    
-  pub fn servers(&mut self, servers: Vec<CallServer>) -> &mut Self {
-    self.inner.servers = servers;
+  pub fn connections(&mut self, connections: Vec<CallConnection>) -> &mut Self {
+    self.inner.connections = connections;
     self
   }
 
@@ -579,12 +575,6 @@ impl RTDCallStateReadyBuilder {
     self
   }
 
-   
-  pub fn allow_p2p(&mut self, allow_p2p: bool) -> &mut Self {
-    self.inner.allow_p2p = allow_p2p;
-    self
-  }
-
 }
 
 impl AsRef<CallStateReady> for CallStateReady {
