@@ -15,30 +15,26 @@ pub struct ChatEventLogFilters {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// True, if message edits need to be returned
+  /// True, if message edits should be returned
   message_edits: bool,
-  /// True, if message deletions need to be returned
+  /// True, if message deletions should be returned
   message_deletions: bool,
-  /// True, if pin/unpin events need to be returned
+  /// True, if pin/unpin events should be returned
   message_pins: bool,
-  /// True, if members joining events need to be returned
+  /// True, if members joining events should be returned
   member_joins: bool,
-  /// True, if members leaving events need to be returned
+  /// True, if members leaving events should be returned
   member_leaves: bool,
-  /// True, if invited member events need to be returned
+  /// True, if invited member events should be returned
   member_invites: bool,
-  /// True, if member promotion/demotion events need to be returned
+  /// True, if member promotion/demotion events should be returned
   member_promotions: bool,
-  /// True, if member restricted/unrestricted/banned/unbanned events need to be returned
+  /// True, if member restricted/unrestricted/banned/unbanned events should be returned
   member_restrictions: bool,
-  /// True, if changes in chat information need to be returned
+  /// True, if changes in chat information should be returned
   info_changes: bool,
-  /// True, if changes in chat settings need to be returned
+  /// True, if changes in chat settings should be returned
   setting_changes: bool,
-  /// True, if changes to invite links need to be returned
-  invite_link_changes: bool,
-  /// True, if video chat actions need to be returned
-  video_chat_changes: bool,
   
 }
 
@@ -79,10 +75,6 @@ impl ChatEventLogFilters {
 
   pub fn setting_changes(&self) -> bool { self.setting_changes }
 
-  pub fn invite_link_changes(&self) -> bool { self.invite_link_changes }
-
-  pub fn video_chat_changes(&self) -> bool { self.video_chat_changes }
-
 }
 
 #[doc(hidden)]
@@ -153,18 +145,6 @@ impl RTDChatEventLogFiltersBuilder {
     self
   }
 
-   
-  pub fn invite_link_changes(&mut self, invite_link_changes: bool) -> &mut Self {
-    self.inner.invite_link_changes = invite_link_changes;
-    self
-  }
-
-   
-  pub fn video_chat_changes(&mut self, video_chat_changes: bool) -> &mut Self {
-    self.inner.video_chat_changes = video_chat_changes;
-    self
-  }
-
 }
 
 impl AsRef<ChatEventLogFilters> for ChatEventLogFilters {
