@@ -19,15 +19,15 @@ pub trait TDChatMemberStatus: Debug + RObject {}
 #[serde(untagged)]
 pub enum ChatMemberStatus {
   #[doc(hidden)] _Default(()),
-  /// The user is a member of the chat and has some additional privileges. In basic groups, administrators can edit and delete messages sent by others, add new members, ban unprivileged members, and manage video chats. In supergroups and channels, there are more detailed options for administrator privileges
+  /// The user is a member of a chat and has some additional privileges. In basic groups, administrators can edit and delete messages sent by others, add new members, and ban unprivileged members. In supergroups and channels, there are more detailed options for administrator privileges
   Administrator(ChatMemberStatusAdministrator),
-  /// The user or the chat was banned (and hence is not a member of the chat). Implies the user can't return to the chat, view messages, or be used as a participant identifier to join a video chat of the chat
+  /// The user was banned (and hence is not a member of the chat). Implies the user can't return to the chat or view messages
   Banned(ChatMemberStatusBanned),
-  /// The user is the owner of the chat and has all the administrator privileges
+  /// The user is the creator of a chat and has all the administrator privileges
   Creator(ChatMemberStatusCreator),
-  /// The user or the chat is not a chat member
+  /// The user is not a chat member
   Left(ChatMemberStatusLeft),
-  /// The user is a member of the chat, without any additional privileges or restrictions
+  /// The user is a member of a chat, without any additional privileges or restrictions
   Member(ChatMemberStatusMember),
   /// The user is under certain restrictions in the chat. Not supported in basic groups and channels
   Restricted(ChatMemberStatusRestricted),
@@ -133,7 +133,7 @@ impl AsRef<ChatMemberStatus> for ChatMemberStatus {
 
 
 
-/// The user is a member of the chat and has some additional privileges. In basic groups, administrators can edit and delete messages sent by others, add new members, ban unprivileged members, and manage video chats. In supergroups and channels, there are more detailed options for administrator privileges
+/// The user is a member of a chat and has some additional privileges. In basic groups, administrators can edit and delete messages sent by others, add new members, and ban unprivileged members. In supergroups and channels, there are more detailed options for administrator privileges
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatMemberStatusAdministrator {
   #[doc(hidden)]
@@ -142,12 +142,8 @@ pub struct ChatMemberStatusAdministrator {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// A custom title of the administrator; 0-16 characters without emojis; applicable to supergroups only
-  custom_title: String,
   /// True, if the current user can edit the administrator privileges for the called user
   can_be_edited: bool,
-  /// True, if the administrator can get chat event log, get chat statistics, get message statistics in channels, get channel members, see anonymous administrators in supergroups and ignore slow mode. Implied by any other privilege; applicable to supergroups and channels only
-  can_manage_chat: bool,
   /// True, if the administrator can change the chat title, photo, and other settings
   can_change_info: bool,
   /// True, if the administrator can create channel posts; applicable to channels only
@@ -158,16 +154,12 @@ pub struct ChatMemberStatusAdministrator {
   can_delete_messages: bool,
   /// True, if the administrator can invite new users to the chat
   can_invite_users: bool,
-  /// True, if the administrator can restrict, ban, or unban chat members; always true for channels
+  /// True, if the administrator can restrict, ban, or unban chat members
   can_restrict_members: bool,
-  /// True, if the administrator can pin messages; applicable to basic groups and supergroups only
+  /// True, if the administrator can pin messages; applicable to supergroups only
   can_pin_messages: bool,
-  /// True, if the administrator can add new administrators with a subset of their own privileges or demote administrators that were directly or indirectly promoted by them
+  /// True, if the administrator can add new administrators with a subset of his own privileges or demote administrators that were directly or indirectly promoted by him
   can_promote_members: bool,
-  /// True, if the administrator can manage video chats
-  can_manage_video_chats: bool,
-  /// True, if the administrator isn't shown in the chat member list and sends messages anonymously; applicable to supergroups only
-  is_anonymous: bool,
   
 }
 
@@ -191,12 +183,8 @@ impl ChatMemberStatusAdministrator {
     RTDChatMemberStatusAdministratorBuilder { inner }
   }
 
-  pub fn custom_title(&self) -> &String { &self.custom_title }
-
   pub fn can_be_edited(&self) -> bool { self.can_be_edited }
 
-  pub fn can_manage_chat(&self) -> bool { self.can_manage_chat }
-
   pub fn can_change_info(&self) -> bool { self.can_change_info }
 
   pub fn can_post_messages(&self) -> bool { self.can_post_messages }
@@ -213,10 +201,6 @@ impl ChatMemberStatusAdministrator {
 
   pub fn can_promote_members(&self) -> bool { self.can_promote_members }
 
-  pub fn can_manage_video_chats(&self) -> bool { self.can_manage_video_chats }
-
-  pub fn is_anonymous(&self) -> bool { self.is_anonymous }
-
 }
 
 #[doc(hidden)]
@@ -228,24 +212,12 @@ impl RTDChatMemberStatusAdministratorBuilder {
   pub fn build(&self) -> ChatMemberStatusAdministrator { self.inner.clone() }
 
    
-  pub fn custom_title<T: AsRef<str>>(&mut self, custom_title: T) -> &mut Self {
-    self.inner.custom_title = custom_title.as_ref().to_string();
-    self
-  }
-
-   
   pub fn can_be_edited(&mut self, can_be_edited: bool) -> &mut Self {
     self.inner.can_be_edited = can_be_edited;
     self
   }
 
    
-  pub fn can_manage_chat(&mut self, can_manage_chat: bool) -> &mut Self {
-    self.inner.can_manage_chat = can_manage_chat;
-    self
-  }
-
-   
   pub fn can_change_info(&mut self, can_change_info: bool) -> &mut Self {
     self.inner.can_change_info = can_change_info;
     self
@@ -293,18 +265,6 @@ impl RTDChatMemberStatusAdministratorBuilder {
     self
   }
 
-   
-  pub fn can_manage_video_chats(&mut self, can_manage_video_chats: bool) -> &mut Self {
-    self.inner.can_manage_video_chats = can_manage_video_chats;
-    self
-  }
-
-   
-  pub fn is_anonymous(&mut self, is_anonymous: bool) -> &mut Self {
-    self.inner.is_anonymous = is_anonymous;
-    self
-  }
-
 }
 
 impl AsRef<ChatMemberStatusAdministrator> for ChatMemberStatusAdministrator {
@@ -321,7 +281,7 @@ impl AsRef<ChatMemberStatusAdministrator> for RTDChatMemberStatusAdministratorBu
 
 
 
-/// The user or the chat was banned (and hence is not a member of the chat). Implies the user can't return to the chat, view messages, or be used as a participant identifier to join a video chat of the chat
+/// The user was banned (and hence is not a member of the chat). Implies the user can't return to the chat or view messages
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatMemberStatusBanned {
   #[doc(hidden)]
@@ -330,7 +290,7 @@ pub struct ChatMemberStatusBanned {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// Point in time (Unix timestamp) when the user will be unbanned; 0 if never. If the user is banned for more than 366 days or for less than 30 seconds from the current time, the user is considered to be banned forever. Always 0 in basic groups
+  /// Point in time (Unix timestamp) when the user will be unbanned; 0 if never. If the user is banned for more than 366 days or for less than 30 seconds from the current time, the user is considered to be banned forever
   banned_until_date: i64,
   
 }
@@ -389,7 +349,7 @@ impl AsRef<ChatMemberStatusBanned> for RTDChatMemberStatusBannedBuilder {
 
 
 
-/// The user is the owner of the chat and has all the administrator privileges
+/// The user is the creator of a chat and has all the administrator privileges
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatMemberStatusCreator {
   #[doc(hidden)]
@@ -398,10 +358,6 @@ pub struct ChatMemberStatusCreator {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// A custom title of the owner; 0-16 characters without emojis; applicable to supergroups only
-  custom_title: String,
-  /// True, if the creator isn't shown in the chat member list and sends messages anonymously; applicable to supergroups only
-  is_anonymous: bool,
   /// True, if the user is a member of the chat
   is_member: bool,
   
@@ -427,10 +383,6 @@ impl ChatMemberStatusCreator {
     RTDChatMemberStatusCreatorBuilder { inner }
   }
 
-  pub fn custom_title(&self) -> &String { &self.custom_title }
-
-  pub fn is_anonymous(&self) -> bool { self.is_anonymous }
-
   pub fn is_member(&self) -> bool { self.is_member }
 
 }
@@ -444,18 +396,6 @@ impl RTDChatMemberStatusCreatorBuilder {
   pub fn build(&self) -> ChatMemberStatusCreator { self.inner.clone() }
 
    
-  pub fn custom_title<T: AsRef<str>>(&mut self, custom_title: T) -> &mut Self {
-    self.inner.custom_title = custom_title.as_ref().to_string();
-    self
-  }
-
-   
-  pub fn is_anonymous(&mut self, is_anonymous: bool) -> &mut Self {
-    self.inner.is_anonymous = is_anonymous;
-    self
-  }
-
-   
   pub fn is_member(&mut self, is_member: bool) -> &mut Self {
     self.inner.is_member = is_member;
     self
@@ -477,7 +417,7 @@ impl AsRef<ChatMemberStatusCreator> for RTDChatMemberStatusCreatorBuilder {
 
 
 
-/// The user or the chat is not a chat member
+/// The user is not a chat member
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatMemberStatusLeft {
   #[doc(hidden)]
@@ -535,7 +475,7 @@ impl AsRef<ChatMemberStatusLeft> for RTDChatMemberStatusLeftBuilder {
 
 
 
-/// The user is a member of the chat, without any additional privileges or restrictions
+/// The user is a member of a chat, without any additional privileges or restrictions
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatMemberStatusMember {
   #[doc(hidden)]
@@ -606,8 +546,14 @@ pub struct ChatMemberStatusRestricted {
   is_member: bool,
   /// Point in time (Unix timestamp) when restrictions will be lifted from the user; 0 if never. If the user is restricted for more than 366 days or for less than 30 seconds from the current time, the user is considered to be restricted forever
   restricted_until_date: i64,
-  /// User permissions in the chat
-  permissions: ChatPermissions,
+  /// True, if the user can send text messages, contacts, locations, and venues
+  can_send_messages: bool,
+  /// True, if the user can send audio files, documents, photos, videos, video notes, and voice notes. Implies can_send_messages permissions
+  can_send_media_messages: bool,
+  /// True, if the user can send animations, games, and stickers and use inline bots. Implies can_send_media_messages permissions
+  can_send_other_messages: bool,
+  /// True, if the user may add a web page preview to his messages. Implies can_send_messages permissions
+  can_add_web_page_previews: bool,
   
 }
 
@@ -635,7 +581,13 @@ impl ChatMemberStatusRestricted {
 
   pub fn restricted_until_date(&self) -> i64 { self.restricted_until_date }
 
-  pub fn permissions(&self) -> &ChatPermissions { &self.permissions }
+  pub fn can_send_messages(&self) -> bool { self.can_send_messages }
+
+  pub fn can_send_media_messages(&self) -> bool { self.can_send_media_messages }
+
+  pub fn can_send_other_messages(&self) -> bool { self.can_send_other_messages }
+
+  pub fn can_add_web_page_previews(&self) -> bool { self.can_add_web_page_previews }
 
 }
 
@@ -660,8 +612,26 @@ impl RTDChatMemberStatusRestrictedBuilder {
   }
 
    
-  pub fn permissions<T: AsRef<ChatPermissions>>(&mut self, permissions: T) -> &mut Self {
-    self.inner.permissions = permissions.as_ref().clone();
+  pub fn can_send_messages(&mut self, can_send_messages: bool) -> &mut Self {
+    self.inner.can_send_messages = can_send_messages;
+    self
+  }
+
+   
+  pub fn can_send_media_messages(&mut self, can_send_media_messages: bool) -> &mut Self {
+    self.inner.can_send_media_messages = can_send_media_messages;
+    self
+  }
+
+   
+  pub fn can_send_other_messages(&mut self, can_send_other_messages: bool) -> &mut Self {
+    self.inner.can_send_other_messages = can_send_other_messages;
+    self
+  }
+
+   
+  pub fn can_add_web_page_previews(&mut self, can_add_web_page_previews: bool) -> &mut Self {
+    self.inner.can_add_web_page_previews = can_add_web_page_previews;
     self
   }
 
