@@ -25,22 +25,18 @@ pub enum InputMessageContent {
   InputMessageAudio(InputMessageAudio),
   /// A message containing a user contact
   InputMessageContact(InputMessageContact),
-  /// A dice message
-  InputMessageDice(InputMessageDice),
   /// A document message (general file)
   InputMessageDocument(InputMessageDocument),
   /// A forwarded message
   InputMessageForwarded(InputMessageForwarded),
   /// A message with a game; not supported for channels or secret chats
   InputMessageGame(InputMessageGame),
-  /// A message with an invoice; can be used only by bots
+  /// A message with an invoice; can be used only by bots and only in private chats
   InputMessageInvoice(InputMessageInvoice),
   /// A message with a location
   InputMessageLocation(InputMessageLocation),
   /// A photo message
   InputMessagePhoto(InputMessagePhoto),
-  /// A message with a poll. Polls can't be sent to secret chats. Polls can be sent only to a private chat with a bot
-  InputMessagePoll(InputMessagePoll),
   /// A sticker message
   InputMessageSticker(InputMessageSticker),
   /// A text message
@@ -68,14 +64,12 @@ impl<'de> Deserialize<'de> for InputMessageContent {
       (inputMessageAnimation, InputMessageAnimation);
       (inputMessageAudio, InputMessageAudio);
       (inputMessageContact, InputMessageContact);
-      (inputMessageDice, InputMessageDice);
       (inputMessageDocument, InputMessageDocument);
       (inputMessageForwarded, InputMessageForwarded);
       (inputMessageGame, InputMessageGame);
       (inputMessageInvoice, InputMessageInvoice);
       (inputMessageLocation, InputMessageLocation);
       (inputMessagePhoto, InputMessagePhoto);
-      (inputMessagePoll, InputMessagePoll);
       (inputMessageSticker, InputMessageSticker);
       (inputMessageText, InputMessageText);
       (inputMessageVenue, InputMessageVenue);
@@ -93,14 +87,12 @@ impl RObject for InputMessageContent {
       InputMessageContent::InputMessageAnimation(t) => t.td_name(),
       InputMessageContent::InputMessageAudio(t) => t.td_name(),
       InputMessageContent::InputMessageContact(t) => t.td_name(),
-      InputMessageContent::InputMessageDice(t) => t.td_name(),
       InputMessageContent::InputMessageDocument(t) => t.td_name(),
       InputMessageContent::InputMessageForwarded(t) => t.td_name(),
       InputMessageContent::InputMessageGame(t) => t.td_name(),
       InputMessageContent::InputMessageInvoice(t) => t.td_name(),
       InputMessageContent::InputMessageLocation(t) => t.td_name(),
       InputMessageContent::InputMessagePhoto(t) => t.td_name(),
-      InputMessageContent::InputMessagePoll(t) => t.td_name(),
       InputMessageContent::InputMessageSticker(t) => t.td_name(),
       InputMessageContent::InputMessageText(t) => t.td_name(),
       InputMessageContent::InputMessageVenue(t) => t.td_name(),
@@ -116,14 +108,12 @@ impl RObject for InputMessageContent {
       InputMessageContent::InputMessageAnimation(t) => t.extra(),
       InputMessageContent::InputMessageAudio(t) => t.extra(),
       InputMessageContent::InputMessageContact(t) => t.extra(),
-      InputMessageContent::InputMessageDice(t) => t.extra(),
       InputMessageContent::InputMessageDocument(t) => t.extra(),
       InputMessageContent::InputMessageForwarded(t) => t.extra(),
       InputMessageContent::InputMessageGame(t) => t.extra(),
       InputMessageContent::InputMessageInvoice(t) => t.extra(),
       InputMessageContent::InputMessageLocation(t) => t.extra(),
       InputMessageContent::InputMessagePhoto(t) => t.extra(),
-      InputMessageContent::InputMessagePoll(t) => t.extra(),
       InputMessageContent::InputMessageSticker(t) => t.extra(),
       InputMessageContent::InputMessageText(t) => t.extra(),
       InputMessageContent::InputMessageVenue(t) => t.extra(),
@@ -144,14 +134,12 @@ impl InputMessageContent {
   pub fn is_input_message_animation(&self) -> bool { if let InputMessageContent::InputMessageAnimation(_) = self { true } else { false } }
   pub fn is_input_message_audio(&self) -> bool { if let InputMessageContent::InputMessageAudio(_) = self { true } else { false } }
   pub fn is_input_message_contact(&self) -> bool { if let InputMessageContent::InputMessageContact(_) = self { true } else { false } }
-  pub fn is_input_message_dice(&self) -> bool { if let InputMessageContent::InputMessageDice(_) = self { true } else { false } }
   pub fn is_input_message_document(&self) -> bool { if let InputMessageContent::InputMessageDocument(_) = self { true } else { false } }
   pub fn is_input_message_forwarded(&self) -> bool { if let InputMessageContent::InputMessageForwarded(_) = self { true } else { false } }
   pub fn is_input_message_game(&self) -> bool { if let InputMessageContent::InputMessageGame(_) = self { true } else { false } }
   pub fn is_input_message_invoice(&self) -> bool { if let InputMessageContent::InputMessageInvoice(_) = self { true } else { false } }
   pub fn is_input_message_location(&self) -> bool { if let InputMessageContent::InputMessageLocation(_) = self { true } else { false } }
   pub fn is_input_message_photo(&self) -> bool { if let InputMessageContent::InputMessagePhoto(_) = self { true } else { false } }
-  pub fn is_input_message_poll(&self) -> bool { if let InputMessageContent::InputMessagePoll(_) = self { true } else { false } }
   pub fn is_input_message_sticker(&self) -> bool { if let InputMessageContent::InputMessageSticker(_) = self { true } else { false } }
   pub fn is_input_message_text(&self) -> bool { if let InputMessageContent::InputMessageText(_) = self { true } else { false } }
   pub fn is_input_message_venue(&self) -> bool { if let InputMessageContent::InputMessageVenue(_) = self { true } else { false } }
@@ -162,14 +150,12 @@ impl InputMessageContent {
   pub fn on_input_message_animation<F: FnOnce(&InputMessageAnimation)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageAnimation(t) = self { fnc(t) }; self }
   pub fn on_input_message_audio<F: FnOnce(&InputMessageAudio)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageAudio(t) = self { fnc(t) }; self }
   pub fn on_input_message_contact<F: FnOnce(&InputMessageContact)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageContact(t) = self { fnc(t) }; self }
-  pub fn on_input_message_dice<F: FnOnce(&InputMessageDice)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageDice(t) = self { fnc(t) }; self }
   pub fn on_input_message_document<F: FnOnce(&InputMessageDocument)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageDocument(t) = self { fnc(t) }; self }
   pub fn on_input_message_forwarded<F: FnOnce(&InputMessageForwarded)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageForwarded(t) = self { fnc(t) }; self }
   pub fn on_input_message_game<F: FnOnce(&InputMessageGame)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageGame(t) = self { fnc(t) }; self }
   pub fn on_input_message_invoice<F: FnOnce(&InputMessageInvoice)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageInvoice(t) = self { fnc(t) }; self }
   pub fn on_input_message_location<F: FnOnce(&InputMessageLocation)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageLocation(t) = self { fnc(t) }; self }
   pub fn on_input_message_photo<F: FnOnce(&InputMessagePhoto)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessagePhoto(t) = self { fnc(t) }; self }
-  pub fn on_input_message_poll<F: FnOnce(&InputMessagePoll)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessagePoll(t) = self { fnc(t) }; self }
   pub fn on_input_message_sticker<F: FnOnce(&InputMessageSticker)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageSticker(t) = self { fnc(t) }; self }
   pub fn on_input_message_text<F: FnOnce(&InputMessageText)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageText(t) = self { fnc(t) }; self }
   pub fn on_input_message_venue<F: FnOnce(&InputMessageVenue)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageVenue(t) = self { fnc(t) }; self }
@@ -180,14 +166,12 @@ impl InputMessageContent {
   pub fn as_input_message_animation(&self) -> Option<&InputMessageAnimation> { if let InputMessageContent::InputMessageAnimation(t) = self { return Some(t) } None }
   pub fn as_input_message_audio(&self) -> Option<&InputMessageAudio> { if let InputMessageContent::InputMessageAudio(t) = self { return Some(t) } None }
   pub fn as_input_message_contact(&self) -> Option<&InputMessageContact> { if let InputMessageContent::InputMessageContact(t) = self { return Some(t) } None }
-  pub fn as_input_message_dice(&self) -> Option<&InputMessageDice> { if let InputMessageContent::InputMessageDice(t) = self { return Some(t) } None }
   pub fn as_input_message_document(&self) -> Option<&InputMessageDocument> { if let InputMessageContent::InputMessageDocument(t) = self { return Some(t) } None }
   pub fn as_input_message_forwarded(&self) -> Option<&InputMessageForwarded> { if let InputMessageContent::InputMessageForwarded(t) = self { return Some(t) } None }
   pub fn as_input_message_game(&self) -> Option<&InputMessageGame> { if let InputMessageContent::InputMessageGame(t) = self { return Some(t) } None }
   pub fn as_input_message_invoice(&self) -> Option<&InputMessageInvoice> { if let InputMessageContent::InputMessageInvoice(t) = self { return Some(t) } None }
   pub fn as_input_message_location(&self) -> Option<&InputMessageLocation> { if let InputMessageContent::InputMessageLocation(t) = self { return Some(t) } None }
   pub fn as_input_message_photo(&self) -> Option<&InputMessagePhoto> { if let InputMessageContent::InputMessagePhoto(t) = self { return Some(t) } None }
-  pub fn as_input_message_poll(&self) -> Option<&InputMessagePoll> { if let InputMessageContent::InputMessagePoll(t) = self { return Some(t) } None }
   pub fn as_input_message_sticker(&self) -> Option<&InputMessageSticker> { if let InputMessageContent::InputMessageSticker(t) = self { return Some(t) } None }
   pub fn as_input_message_text(&self) -> Option<&InputMessageText> { if let InputMessageContent::InputMessageText(t) = self { return Some(t) } None }
   pub fn as_input_message_venue(&self) -> Option<&InputMessageVenue> { if let InputMessageContent::InputMessageVenue(t) = self { return Some(t) } None }
@@ -203,8 +187,6 @@ impl InputMessageContent {
 
   pub fn input_message_contact<T: AsRef<InputMessageContact>>(t: T) -> Self { InputMessageContent::InputMessageContact(t.as_ref().clone()) }
 
-  pub fn input_message_dice<T: AsRef<InputMessageDice>>(t: T) -> Self { InputMessageContent::InputMessageDice(t.as_ref().clone()) }
-
   pub fn input_message_document<T: AsRef<InputMessageDocument>>(t: T) -> Self { InputMessageContent::InputMessageDocument(t.as_ref().clone()) }
 
   pub fn input_message_forwarded<T: AsRef<InputMessageForwarded>>(t: T) -> Self { InputMessageContent::InputMessageForwarded(t.as_ref().clone()) }
@@ -217,8 +199,6 @@ impl InputMessageContent {
 
   pub fn input_message_photo<T: AsRef<InputMessagePhoto>>(t: T) -> Self { InputMessageContent::InputMessagePhoto(t.as_ref().clone()) }
 
-  pub fn input_message_poll<T: AsRef<InputMessagePoll>>(t: T) -> Self { InputMessageContent::InputMessagePoll(t.as_ref().clone()) }
-
   pub fn input_message_sticker<T: AsRef<InputMessageSticker>>(t: T) -> Self { InputMessageContent::InputMessageSticker(t.as_ref().clone()) }
 
   pub fn input_message_text<T: AsRef<InputMessageText>>(t: T) -> Self { InputMessageContent::InputMessageText(t.as_ref().clone()) }
@@ -254,17 +234,15 @@ pub struct InputMessageAnimation {
   extra: Option<String>,
   /// Animation file to be sent
   animation: InputFile,
-  /// Animation thumbnail; pass null to skip thumbnail uploading
+  /// Animation thumbnail, if available
   thumbnail: InputThumbnail,
-  /// File identifiers of the stickers added to the animation, if applicable
-  added_sticker_file_ids: Vec<i64>,
   /// Duration of the animation, in seconds
   duration: i64,
   /// Width of the animation; may be replaced by the server
   width: i64,
   /// Height of the animation; may be replaced by the server
   height: i64,
-  /// Animation caption; pass null to use an empty caption; 0-GetOption("message_caption_length_max") characters
+  /// Animation caption; 0-GetOption("message_caption_length_max") characters
   caption: FormattedText,
   
 }
@@ -293,8 +271,6 @@ impl InputMessageAnimation {
 
   pub fn thumbnail(&self) -> &InputThumbnail { &self.thumbnail }
 
-  pub fn added_sticker_file_ids(&self) -> &Vec<i64> { &self.added_sticker_file_ids }
-
   pub fn duration(&self) -> i64 { self.duration }
 
   pub fn width(&self) -> i64 { self.width }
@@ -326,12 +302,6 @@ impl RTDInputMessageAnimationBuilder {
   }
 
    
-  pub fn added_sticker_file_ids(&mut self, added_sticker_file_ids: Vec<i64>) -> &mut Self {
-    self.inner.added_sticker_file_ids = added_sticker_file_ids;
-    self
-  }
-
-   
   pub fn duration(&mut self, duration: i64) -> &mut Self {
     self.inner.duration = duration;
     self
@@ -382,7 +352,7 @@ pub struct InputMessageAudio {
   extra: Option<String>,
   /// Audio file to be sent
   audio: InputFile,
-  /// Thumbnail of the cover for the album; pass null to skip thumbnail uploading
+  /// Thumbnail of the cover for the album, if available
   album_cover_thumbnail: InputThumbnail,
   /// Duration of the audio, in seconds; may be replaced by the server
   duration: i64,
@@ -390,7 +360,7 @@ pub struct InputMessageAudio {
   title: String,
   /// Performer of the audio; 0-64 characters, may be replaced by the server
   performer: String,
-  /// Audio caption; pass null to use an empty caption; 0-GetOption("message_caption_length_max") characters
+  /// Audio caption; 0-GetOption("message_caption_length_max") characters
   caption: FormattedText,
   
 }
@@ -557,84 +527,6 @@ impl AsRef<InputMessageContact> for RTDInputMessageContactBuilder {
 
 
 
-/// A dice message
-#[derive(Debug, Clone, Default, Serialize, Deserialize)]
-pub struct InputMessageDice {
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@type", deserialize = "@type"))]
-  td_name: String,
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
-  extra: Option<String>,
-  /// Emoji on which the dice throw animation is based
-  emoji: String,
-  /// True, if the chat message draft must be deleted
-  clear_draft: bool,
-  
-}
-
-impl RObject for InputMessageDice {
-  #[doc(hidden)] fn td_name(&self) -> &'static str { "inputMessageDice" }
-  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
-  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
-}
-
-
-impl TDInputMessageContent for InputMessageDice {}
-
-
-
-impl InputMessageDice {
-  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
-  pub fn builder() -> RTDInputMessageDiceBuilder {
-    let mut inner = InputMessageDice::default();
-    inner.td_name = "inputMessageDice".to_string();
-    inner.extra = Some(Uuid::new_v4().to_string());
-    RTDInputMessageDiceBuilder { inner }
-  }
-
-  pub fn emoji(&self) -> &String { &self.emoji }
-
-  pub fn clear_draft(&self) -> bool { self.clear_draft }
-
-}
-
-#[doc(hidden)]
-pub struct RTDInputMessageDiceBuilder {
-  inner: InputMessageDice
-}
-
-impl RTDInputMessageDiceBuilder {
-  pub fn build(&self) -> InputMessageDice { self.inner.clone() }
-
-   
-  pub fn emoji<T: AsRef<str>>(&mut self, emoji: T) -> &mut Self {
-    self.inner.emoji = emoji.as_ref().to_string();
-    self
-  }
-
-   
-  pub fn clear_draft(&mut self, clear_draft: bool) -> &mut Self {
-    self.inner.clear_draft = clear_draft;
-    self
-  }
-
-}
-
-impl AsRef<InputMessageDice> for InputMessageDice {
-  fn as_ref(&self) -> &InputMessageDice { self }
-}
-
-impl AsRef<InputMessageDice> for RTDInputMessageDiceBuilder {
-  fn as_ref(&self) -> &InputMessageDice { &self.inner }
-}
-
-
-
-
-
-
-
 /// A document message (general file)
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct InputMessageDocument {
@@ -646,11 +538,9 @@ pub struct InputMessageDocument {
   extra: Option<String>,
   /// Document to be sent
   document: InputFile,
-  /// Document thumbnail; pass null to skip thumbnail uploading
+  /// Document thumbnail, if available
   thumbnail: InputThumbnail,
-  /// If true, automatic file type detection will be disabled and the document will be always sent as file. Always true for files sent to secret chats
-  disable_content_type_detection: bool,
-  /// Document caption; pass null to use an empty caption; 0-GetOption("message_caption_length_max") characters
+  /// Document caption; 0-GetOption("message_caption_length_max") characters
   caption: FormattedText,
   
 }
@@ -679,8 +569,6 @@ impl InputMessageDocument {
 
   pub fn thumbnail(&self) -> &InputThumbnail { &self.thumbnail }
 
-  pub fn disable_content_type_detection(&self) -> bool { self.disable_content_type_detection }
-
   pub fn caption(&self) -> &FormattedText { &self.caption }
 
 }
@@ -706,12 +594,6 @@ impl RTDInputMessageDocumentBuilder {
   }
 
    
-  pub fn disable_content_type_detection(&mut self, disable_content_type_detection: bool) -> &mut Self {
-    self.inner.disable_content_type_detection = disable_content_type_detection;
-    self
-  }
-
-   
   pub fn caption<T: AsRef<FormattedText>>(&mut self, caption: T) -> &mut Self {
     self.inner.caption = caption.as_ref().clone();
     self
@@ -746,10 +628,8 @@ pub struct InputMessageForwarded {
   from_chat_id: i64,
   /// Identifier of the message to forward
   message_id: i64,
-  /// True, if a game message is being shared from a launched game; applies only to game messages
+  /// True, if a game message should be shared within a launched game; applies only to game messages
   in_game_share: bool,
-  /// Options to be used to copy content of the message without reference to the original sender; pass null to forward the message as usual
-  copy_options: MessageCopyOptions,
   
 }
 
@@ -779,8 +659,6 @@ impl InputMessageForwarded {
 
   pub fn in_game_share(&self) -> bool { self.in_game_share }
 
-  pub fn copy_options(&self) -> &MessageCopyOptions { &self.copy_options }
-
 }
 
 #[doc(hidden)]
@@ -809,12 +687,6 @@ impl RTDInputMessageForwardedBuilder {
     self
   }
 
-   
-  pub fn copy_options<T: AsRef<MessageCopyOptions>>(&mut self, copy_options: T) -> &mut Self {
-    self.inner.copy_options = copy_options.as_ref().clone();
-    self
-  }
-
 }
 
 impl AsRef<InputMessageForwarded> for InputMessageForwarded {
@@ -909,7 +781,7 @@ impl AsRef<InputMessageGame> for RTDInputMessageGameBuilder {
 
 
 
-/// A message with an invoice; can be used only by bots
+/// A message with an invoice; can be used only by bots and only in private chats
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct InputMessageInvoice {
   #[doc(hidden)]
@@ -922,7 +794,7 @@ pub struct InputMessageInvoice {
   invoice: Invoice,
   /// Product title; 1-32 characters
   title: String,
-  /// A message with an invoice; can be used only by bots
+  /// A message with an invoice; can be used only by bots and only in private chats
   description: String,
   /// Product photo URL; optional
   photo_url: String,
@@ -938,7 +810,7 @@ pub struct InputMessageInvoice {
   provider_token: String,
   /// JSON-encoded data about the invoice, which will be shared with the payment provider
   provider_data: String,
-  /// Unique invoice bot deep link parameter for the generation of this invoice. If empty, it would be possible to pay directly from forwards of the invoice message
+  /// Unique invoice bot start_parameter for the generation of this invoice
   start_parameter: String,
   
 }
@@ -1088,12 +960,8 @@ pub struct InputMessageLocation {
   extra: Option<String>,
   /// Location to be sent
   location: Location,
-  /// Period for which the location can be updated, in seconds; must be between 60 and 86400 for a live location and 0 otherwise
+  /// Period for which the location can be updated, in seconds; should bebetween 60 and 86400 for a live location and 0 otherwise
   live_period: i64,
-  /// For live locations, a direction in which the location moves, in degrees; 1-360. Pass 0 if unknown
-  heading: i64,
-  /// For live locations, a maximum distance to another chat member for proximity alerts, in meters (0-100000). Pass 0 if the notification is disabled. Can't be enabled in channels and Saved Messages
-  proximity_alert_radius: i64,
   
 }
 
@@ -1121,10 +989,6 @@ impl InputMessageLocation {
 
   pub fn live_period(&self) -> i64 { self.live_period }
 
-  pub fn heading(&self) -> i64 { self.heading }
-
-  pub fn proximity_alert_radius(&self) -> i64 { self.proximity_alert_radius }
-
 }
 
 #[doc(hidden)]
@@ -1147,18 +1011,6 @@ impl RTDInputMessageLocationBuilder {
     self
   }
 
-   
-  pub fn heading(&mut self, heading: i64) -> &mut Self {
-    self.inner.heading = heading;
-    self
-  }
-
-   
-  pub fn proximity_alert_radius(&mut self, proximity_alert_radius: i64) -> &mut Self {
-    self.inner.proximity_alert_radius = proximity_alert_radius;
-    self
-  }
-
 }
 
 impl AsRef<InputMessageLocation> for InputMessageLocation {
@@ -1186,7 +1038,7 @@ pub struct InputMessagePhoto {
   extra: Option<String>,
   /// Photo to send
   photo: InputFile,
-  /// Photo thumbnail to be sent; pass null to skip thumbnail uploading. The thumbnail is sent to the other party only in secret chats
+  /// Photo thumbnail to be sent, this is sent to the other party in secret chats only
   thumbnail: InputThumbnail,
   /// File identifiers of the stickers added to the photo, if applicable
   added_sticker_file_ids: Vec<i64>,
@@ -1194,7 +1046,7 @@ pub struct InputMessagePhoto {
   width: i64,
   /// Photo height
   height: i64,
-  /// Photo caption; pass null to use an empty caption; 0-GetOption("message_caption_length_max") characters
+  /// Photo caption; 0-GetOption("message_caption_length_max") characters
   caption: FormattedText,
   /// Photo TTL (Time To Live), in seconds (0-60). A non-zero TTL can be specified only in private chats
   ttl: i64,
@@ -1303,134 +1155,6 @@ impl AsRef<InputMessagePhoto> for RTDInputMessagePhotoBuilder {
 
 
 
-/// A message with a poll. Polls can't be sent to secret chats. Polls can be sent only to a private chat with a bot
-#[derive(Debug, Clone, Default, Serialize, Deserialize)]
-pub struct InputMessagePoll {
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@type", deserialize = "@type"))]
-  td_name: String,
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
-  extra: Option<String>,
-  /// Poll question; 1-255 characters (up to 300 characters for bots)
-  question: String,
-  /// List of poll answer options, 2-10 strings 1-100 characters each
-  options: Vec<String>,
-  /// True, if the poll voters are anonymous. Non-anonymous polls can't be sent or forwarded to channels
-  is_anonymous: bool,
-  /// Type of the poll
-  #[serde(rename(serialize = "type", deserialize = "type"))] type_: PollType,
-  /// Amount of time the poll will be active after creation, in seconds; for bots only
-  open_period: i64,
-  /// Point in time (Unix timestamp) when the poll will automatically be closed; for bots only
-  close_date: i64,
-  /// True, if the poll needs to be sent already closed; for bots only
-  is_closed: bool,
-  
-}
-
-impl RObject for InputMessagePoll {
-  #[doc(hidden)] fn td_name(&self) -> &'static str { "inputMessagePoll" }
-  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
-  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
-}
-
-
-impl TDInputMessageContent for InputMessagePoll {}
-
-
-
-impl InputMessagePoll {
-  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
-  pub fn builder() -> RTDInputMessagePollBuilder {
-    let mut inner = InputMessagePoll::default();
-    inner.td_name = "inputMessagePoll".to_string();
-    inner.extra = Some(Uuid::new_v4().to_string());
-    RTDInputMessagePollBuilder { inner }
-  }
-
-  pub fn question(&self) -> &String { &self.question }
-
-  pub fn options(&self) -> &Vec<String> { &self.options }
-
-  pub fn is_anonymous(&self) -> bool { self.is_anonymous }
-
-  pub fn type_(&self) -> &PollType { &self.type_ }
-
-  pub fn open_period(&self) -> i64 { self.open_period }
-
-  pub fn close_date(&self) -> i64 { self.close_date }
-
-  pub fn is_closed(&self) -> bool { self.is_closed }
-
-}
-
-#[doc(hidden)]
-pub struct RTDInputMessagePollBuilder {
-  inner: InputMessagePoll
-}
-
-impl RTDInputMessagePollBuilder {
-  pub fn build(&self) -> InputMessagePoll { self.inner.clone() }
-
-   
-  pub fn question<T: AsRef<str>>(&mut self, question: T) -> &mut Self {
-    self.inner.question = question.as_ref().to_string();
-    self
-  }
-
-   
-  pub fn options(&mut self, options: Vec<String>) -> &mut Self {
-    self.inner.options = options;
-    self
-  }
-
-   
-  pub fn is_anonymous(&mut self, is_anonymous: bool) -> &mut Self {
-    self.inner.is_anonymous = is_anonymous;
-    self
-  }
-
-   
-  pub fn type_<T: AsRef<PollType>>(&mut self, type_: T) -> &mut Self {
-    self.inner.type_ = type_.as_ref().clone();
-    self
-  }
-
-   
-  pub fn open_period(&mut self, open_period: i64) -> &mut Self {
-    self.inner.open_period = open_period;
-    self
-  }
-
-   
-  pub fn close_date(&mut self, close_date: i64) -> &mut Self {
-    self.inner.close_date = close_date;
-    self
-  }
-
-   
-  pub fn is_closed(&mut self, is_closed: bool) -> &mut Self {
-    self.inner.is_closed = is_closed;
-    self
-  }
-
-}
-
-impl AsRef<InputMessagePoll> for InputMessagePoll {
-  fn as_ref(&self) -> &InputMessagePoll { self }
-}
-
-impl AsRef<InputMessagePoll> for RTDInputMessagePollBuilder {
-  fn as_ref(&self) -> &InputMessagePoll { &self.inner }
-}
-
-
-
-
-
-
-
 /// A sticker message
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct InputMessageSticker {
@@ -1442,14 +1166,12 @@ pub struct InputMessageSticker {
   extra: Option<String>,
   /// Sticker to be sent
   sticker: InputFile,
-  /// Sticker thumbnail; pass null to skip thumbnail uploading
+  /// Sticker thumbnail, if available
   thumbnail: InputThumbnail,
   /// Sticker width
   width: i64,
   /// Sticker height
   height: i64,
-  /// Emoji used to choose the sticker
-  emoji: String,
   
 }
 
@@ -1481,8 +1203,6 @@ impl InputMessageSticker {
 
   pub fn height(&self) -> i64 { self.height }
 
-  pub fn emoji(&self) -> &String { &self.emoji }
-
 }
 
 #[doc(hidden)]
@@ -1517,12 +1237,6 @@ impl RTDInputMessageStickerBuilder {
     self
   }
 
-   
-  pub fn emoji<T: AsRef<str>>(&mut self, emoji: T) -> &mut Self {
-    self.inner.emoji = emoji.as_ref().to_string();
-    self
-  }
-
 }
 
 impl AsRef<InputMessageSticker> for InputMessageSticker {
@@ -1548,11 +1262,11 @@ pub struct InputMessageText {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// Formatted text to be sent; 1-GetOption("message_text_length_max") characters. Only Bold, Italic, Underline, Strikethrough, Spoiler, Code, Pre, PreCode, TextUrl and MentionName entities are allowed to be specified manually
+  /// Formatted text to be sent; 1-GetOption("message_text_length_max") characters. Only Bold, Italic, Code, Pre, PreCode and TextUrl entities are allowed to be specified manually
   text: FormattedText,
-  /// True, if rich web page previews for URLs in the message text must be disabled
+  /// True, if rich web page previews for URLs in the message text should be disabled
   disable_web_page_preview: bool,
-  /// True, if a chat message draft must be deleted
+  /// True, if a chat message draft should be deleted
   clear_draft: bool,
   
 }
@@ -1706,7 +1420,7 @@ pub struct InputMessageVideo {
   extra: Option<String>,
   /// Video to be sent
   video: InputFile,
-  /// Video thumbnail; pass null to skip thumbnail uploading
+  /// Video thumbnail, if available
   thumbnail: InputThumbnail,
   /// File identifiers of the stickers added to the video, if applicable
   added_sticker_file_ids: Vec<i64>,
@@ -1716,9 +1430,9 @@ pub struct InputMessageVideo {
   width: i64,
   /// Video height
   height: i64,
-  /// True, if the video is supposed to be streamed
+  /// True, if the video should be tried to be streamed
   supports_streaming: bool,
-  /// Video caption; pass null to use an empty caption; 0-GetOption("message_caption_length_max") characters
+  /// Video caption; 0-GetOption("message_caption_length_max") characters
   caption: FormattedText,
   /// Video TTL (Time To Live), in seconds (0-60). A non-zero TTL can be specified only in private chats
   ttl: i64,
@@ -1854,7 +1568,7 @@ pub struct InputMessageVideoNote {
   extra: Option<String>,
   /// Video note to be sent
   video_note: InputFile,
-  /// Video thumbnail; pass null to skip thumbnail uploading
+  /// Video thumbnail, if available
   thumbnail: InputThumbnail,
   /// Duration of the video, in seconds
   duration: i64,
@@ -1956,7 +1670,7 @@ pub struct InputMessageVoiceNote {
   duration: i64,
   /// Waveform representation of the voice note, in 5-bit format
   waveform: String,
-  /// Voice note caption; pass null to use an empty caption; 0-GetOption("message_caption_length_max") characters
+  /// Voice note caption; 0-GetOption("message_caption_length_max") characters
   caption: FormattedText,
   
 }
