@@ -240,8 +240,6 @@ pub struct PassportElementErrorSourceFile {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// Index of a file with the error
-  file_index: i64,
   
 }
 
@@ -265,8 +263,6 @@ impl PassportElementErrorSourceFile {
     RTDPassportElementErrorSourceFileBuilder { inner }
   }
 
-  pub fn file_index(&self) -> i64 { self.file_index }
-
 }
 
 #[doc(hidden)]
@@ -277,12 +273,6 @@ pub struct RTDPassportElementErrorSourceFileBuilder {
 impl RTDPassportElementErrorSourceFileBuilder {
   pub fn build(&self) -> PassportElementErrorSourceFile { self.inner.clone() }
 
-   
-  pub fn file_index(&mut self, file_index: i64) -> &mut Self {
-    self.inner.file_index = file_index;
-    self
-  }
-
 }
 
 impl AsRef<PassportElementErrorSourceFile> for PassportElementErrorSourceFile {
@@ -540,8 +530,6 @@ pub struct PassportElementErrorSourceTranslationFile {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// Index of a file with the error
-  file_index: i64,
   
 }
 
@@ -565,8 +553,6 @@ impl PassportElementErrorSourceTranslationFile {
     RTDPassportElementErrorSourceTranslationFileBuilder { inner }
   }
 
-  pub fn file_index(&self) -> i64 { self.file_index }
-
 }
 
 #[doc(hidden)]
@@ -577,12 +563,6 @@ pub struct RTDPassportElementErrorSourceTranslationFileBuilder {
 impl RTDPassportElementErrorSourceTranslationFileBuilder {
   pub fn build(&self) -> PassportElementErrorSourceTranslationFile { self.inner.clone() }
 
-   
-  pub fn file_index(&mut self, file_index: i64) -> &mut Self {
-    self.inner.file_index = file_index;
-    self
-  }
-
 }
 
 impl AsRef<PassportElementErrorSourceTranslationFile> for PassportElementErrorSourceTranslationFile {
