@@ -23,16 +23,12 @@ pub struct Sticker {
   height: i64,
   /// Emoji corresponding to the sticker
   emoji: String,
-  /// True, if the sticker is an animated sticker in TGS format
-  is_animated: bool,
   /// True, if the sticker is a mask
   is_mask: bool,
-  /// Position where the mask is placed; may be null
+  /// Position where the mask should be placed; may be null
   mask_position: Option<MaskPosition>,
-  /// Sticker's outline represented as a list of closed vector paths; may be empty. The coordinate system origin is in the upper-left corner
-  outline: Vec<ClosedVectorPath>,
   /// Sticker thumbnail in WEBP or JPEG format; may be null
-  thumbnail: Option<Thumbnail>,
+  thumbnail: Option<PhotoSize>,
   /// File containing the sticker
   sticker: File,
   
@@ -63,15 +59,11 @@ impl Sticker {
 
   pub fn emoji(&self) -> &String { &self.emoji }
 
-  pub fn is_animated(&self) -> bool { self.is_animated }
-
   pub fn is_mask(&self) -> bool { self.is_mask }
 
   pub fn mask_position(&self) -> &Option<MaskPosition> { &self.mask_position }
 
-  pub fn outline(&self) -> &Vec<ClosedVectorPath> { &self.outline }
-
-  pub fn thumbnail(&self) -> &Option<Thumbnail> { &self.thumbnail }
+  pub fn thumbnail(&self) -> &Option<PhotoSize> { &self.thumbnail }
 
   pub fn sticker(&self) -> &File { &self.sticker }
 
@@ -110,12 +102,6 @@ impl RTDStickerBuilder {
   }
 
    
-  pub fn is_animated(&mut self, is_animated: bool) -> &mut Self {
-    self.inner.is_animated = is_animated;
-    self
-  }
-
-   
   pub fn is_mask(&mut self, is_mask: bool) -> &mut Self {
     self.inner.is_mask = is_mask;
     self
@@ -128,13 +114,7 @@ impl RTDStickerBuilder {
   }
 
    
-  pub fn outline(&mut self, outline: Vec<ClosedVectorPath>) -> &mut Self {
-    self.inner.outline = outline;
-    self
-  }
-
-   
-  pub fn thumbnail<T: AsRef<Thumbnail>>(&mut self, thumbnail: T) -> &mut Self {
+  pub fn thumbnail<T: AsRef<PhotoSize>>(&mut self, thumbnail: T) -> &mut Self {
     self.inner.thumbnail = Some(thumbnail.as_ref().clone());
     self
   }
