@@ -21,25 +21,19 @@ pub struct StickerSetInfo {
   title: String,
   /// Name of the sticker set
   name: String,
-  /// Sticker set thumbnail in WEBP or TGS format with width and height 100; may be null
-  thumbnail: Option<Thumbnail>,
-  /// Sticker set thumbnail's outline represented as a list of closed vector paths; may be empty. The coordinate system origin is in the upper-left corner
-  thumbnail_outline: Vec<ClosedVectorPath>,
-  /// True, if the sticker set has been installed by the current user
+  /// True, if the sticker set has been installed by current user
   is_installed: bool,
   /// True, if the sticker set has been archived. A sticker set can't be installed and archived simultaneously
   is_archived: bool,
   /// True, if the sticker set is official
   is_official: bool,
-  /// True, is the stickers in the set are animated
-  is_animated: bool,
   /// True, if the stickers in the set are masks
   is_masks: bool,
   /// True for already viewed trending sticker sets
   is_viewed: bool,
   /// Total number of stickers in the set
   size: i64,
-  /// Up to the first 5 stickers from the set, depending on the context. If the application needs more stickers the full sticker set needs to be requested
+  /// Contains up to the first 5 stickers from the set, depending on the context. If the client needs more stickers the full set should be requested
   covers: Vec<Sticker>,
   
 }
@@ -67,18 +61,12 @@ impl StickerSetInfo {
 
   pub fn name(&self) -> &String { &self.name }
 
-  pub fn thumbnail(&self) -> &Option<Thumbnail> { &self.thumbnail }
-
-  pub fn thumbnail_outline(&self) -> &Vec<ClosedVectorPath> { &self.thumbnail_outline }
-
   pub fn is_installed(&self) -> bool { self.is_installed }
 
   pub fn is_archived(&self) -> bool { self.is_archived }
 
   pub fn is_official(&self) -> bool { self.is_official }
 
-  pub fn is_animated(&self) -> bool { self.is_animated }
-
   pub fn is_masks(&self) -> bool { self.is_masks }
 
   pub fn is_viewed(&self) -> bool { self.is_viewed }
@@ -116,18 +104,6 @@ impl RTDStickerSetInfoBuilder {
   }
 
    
-  pub fn thumbnail<T: AsRef<Thumbnail>>(&mut self, thumbnail: T) -> &mut Self {
-    self.inner.thumbnail = Some(thumbnail.as_ref().clone());
-    self
-  }
-
-   
-  pub fn thumbnail_outline(&mut self, thumbnail_outline: Vec<ClosedVectorPath>) -> &mut Self {
-    self.inner.thumbnail_outline = thumbnail_outline;
-    self
-  }
-
-   
   pub fn is_installed(&mut self, is_installed: bool) -> &mut Self {
     self.inner.is_installed = is_installed;
     self
@@ -146,12 +122,6 @@ impl RTDStickerSetInfoBuilder {
   }
 
    
-  pub fn is_animated(&mut self, is_animated: bool) -> &mut Self {
-    self.inner.is_animated = is_animated;
-    self
-  }
-
-   
   pub fn is_masks(&mut self, is_masks: bool) -> &mut Self {
     self.inner.is_masks = is_masks;
     self
