@@ -19,13 +19,11 @@ pub trait TDTextEntityType: Debug + RObject {}
 #[serde(untagged)]
 pub enum TextEntityType {
   #[doc(hidden)] _Default(()),
-  /// A bank card number. The getBankCardInfo method can be used to get information about the bank card
-  BankCardNumber(TextEntityTypeBankCardNumber),
   /// A bold text
   Bold(TextEntityTypeBold),
-  /// A bot command, beginning with "/"
+  /// A bot command, beginning with "/". This shouldn't be highlighted if there are no bots in the chat
   BotCommand(TextEntityTypeBotCommand),
-  /// A cashtag text, beginning with "$" and consisting of capital English letters (e.g., "$USD")
+  /// A cashtag text, beginning with "$" and consisting of capital english letters (i.e. "$USD")
   Cashtag(TextEntityTypeCashtag),
   /// Text that must be formatted as if inside a code HTML tag
   Code(TextEntityTypeCode),
@@ -35,8 +33,6 @@ pub enum TextEntityType {
   Hashtag(TextEntityTypeHashtag),
   /// An italic text
   Italic(TextEntityTypeItalic),
-  /// A media timestamp
-  MediaTimestamp(TextEntityTypeMediaTimestamp),
   /// A mention of a user by their username
   Mention(TextEntityTypeMention),
   /// A text shows instead of a raw mention of the user (e.g., when the user has no username)
@@ -47,14 +43,8 @@ pub enum TextEntityType {
   Pre(TextEntityTypePre),
   /// Text that must be formatted as if inside pre, and code HTML tags
   PreCode(TextEntityTypePreCode),
-  /// A spoiler text. Not supported in secret chats
-  Spoiler(TextEntityTypeSpoiler),
-  /// A strikethrough text
-  Strikethrough(TextEntityTypeStrikethrough),
   /// A text description shown instead of a raw URL
   TextUrl(TextEntityTypeTextUrl),
-  /// An underlined text
-  Underline(TextEntityTypeUnderline),
   /// An HTTP URL
   Url(TextEntityTypeUrl),
 
@@ -69,7 +59,6 @@ impl<'de> Deserialize<'de> for TextEntityType {
     use serde::de::Error;
     rtd_enum_deserialize!(
       TextEntityType,
-      (textEntityTypeBankCardNumber, BankCardNumber);
       (textEntityTypeBold, Bold);
       (textEntityTypeBotCommand, BotCommand);
       (textEntityTypeCashtag, Cashtag);
@@ -77,16 +66,12 @@ impl<'de> Deserialize<'de> for TextEntityType {
       (textEntityTypeEmailAddress, EmailAddress);
       (textEntityTypeHashtag, Hashtag);
       (textEntityTypeItalic, Italic);
-      (textEntityTypeMediaTimestamp, MediaTimestamp);
       (textEntityTypeMention, Mention);
       (textEntityTypeMentionName, MentionName);
       (textEntityTypePhoneNumber, PhoneNumber);
       (textEntityTypePre, Pre);
       (textEntityTypePreCode, PreCode);
-      (textEntityTypeSpoiler, Spoiler);
-      (textEntityTypeStrikethrough, Strikethrough);
       (textEntityTypeTextUrl, TextUrl);
-      (textEntityTypeUnderline, Underline);
       (textEntityTypeUrl, Url);
 
     )(deserializer)
@@ -96,7 +81,6 @@ impl<'de> Deserialize<'de> for TextEntityType {
 impl RObject for TextEntityType {
   #[doc(hidden)] fn td_name(&self) -> &'static str {
     match self {
-      TextEntityType::BankCardNumber(t) => t.td_name(),
       TextEntityType::Bold(t) => t.td_name(),
       TextEntityType::BotCommand(t) => t.td_name(),
       TextEntityType::Cashtag(t) => t.td_name(),
@@ -104,16 +88,12 @@ impl RObject for TextEntityType {
       TextEntityType::EmailAddress(t) => t.td_name(),
       TextEntityType::Hashtag(t) => t.td_name(),
       TextEntityType::Italic(t) => t.td_name(),
-      TextEntityType::MediaTimestamp(t) => t.td_name(),
       TextEntityType::Mention(t) => t.td_name(),
       TextEntityType::MentionName(t) => t.td_name(),
       TextEntityType::PhoneNumber(t) => t.td_name(),
       TextEntityType::Pre(t) => t.td_name(),
       TextEntityType::PreCode(t) => t.td_name(),
-      TextEntityType::Spoiler(t) => t.td_name(),
-      TextEntityType::Strikethrough(t) => t.td_name(),
       TextEntityType::TextUrl(t) => t.td_name(),
-      TextEntityType::Underline(t) => t.td_name(),
       TextEntityType::Url(t) => t.td_name(),
 
       _ => "-1",
@@ -121,7 +101,6 @@ impl RObject for TextEntityType {
   }
   #[doc(hidden)] fn extra(&self) -> Option<String> {
     match self {
-      TextEntityType::BankCardNumber(t) => t.extra(),
       TextEntityType::Bold(t) => t.extra(),
       TextEntityType::BotCommand(t) => t.extra(),
       TextEntityType::Cashtag(t) => t.extra(),
@@ -129,16 +108,12 @@ impl RObject for TextEntityType {
       TextEntityType::EmailAddress(t) => t.extra(),
       TextEntityType::Hashtag(t) => t.extra(),
       TextEntityType::Italic(t) => t.extra(),
-      TextEntityType::MediaTimestamp(t) => t.extra(),
       TextEntityType::Mention(t) => t.extra(),
       TextEntityType::MentionName(t) => t.extra(),
       TextEntityType::PhoneNumber(t) => t.extra(),
       TextEntityType::Pre(t) => t.extra(),
       TextEntityType::PreCode(t) => t.extra(),
-      TextEntityType::Spoiler(t) => t.extra(),
-      TextEntityType::Strikethrough(t) => t.extra(),
       TextEntityType::TextUrl(t) => t.extra(),
-      TextEntityType::Underline(t) => t.extra(),
       TextEntityType::Url(t) => t.extra(),
 
       _ => None,
@@ -151,7 +126,6 @@ impl TextEntityType {
   pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
   #[doc(hidden)] pub fn _is_default(&self) -> bool { if let TextEntityType::_Default(_) = self { true } else { false } }
 
-  pub fn is_bank_card_number(&self) -> bool { if let TextEntityType::BankCardNumber(_) = self { true } else { false } }
   pub fn is_bold(&self) -> bool { if let TextEntityType::Bold(_) = self { true } else { false } }
   pub fn is_bot_command(&self) -> bool { if let TextEntityType::BotCommand(_) = self { true } else { false } }
   pub fn is_cashtag(&self) -> bool { if let TextEntityType::Cashtag(_) = self { true } else { false } }
@@ -159,19 +133,14 @@ impl TextEntityType {
   pub fn is_email_address(&self) -> bool { if let TextEntityType::EmailAddress(_) = self { true } else { false } }
   pub fn is_hashtag(&self) -> bool { if let TextEntityType::Hashtag(_) = self { true } else { false } }
   pub fn is_italic(&self) -> bool { if let TextEntityType::Italic(_) = self { true } else { false } }
-  pub fn is_media_timestamp(&self) -> bool { if let TextEntityType::MediaTimestamp(_) = self { true } else { false } }
   pub fn is_mention(&self) -> bool { if let TextEntityType::Mention(_) = self { true } else { false } }
   pub fn is_mention_name(&self) -> bool { if let TextEntityType::MentionName(_) = self { true } else { false } }
   pub fn is_phone_number(&self) -> bool { if let TextEntityType::PhoneNumber(_) = self { true } else { false } }
   pub fn is_pre(&self) -> bool { if let TextEntityType::Pre(_) = self { true } else { false } }
   pub fn is_pre_code(&self) -> bool { if let TextEntityType::PreCode(_) = self { true } else { false } }
-  pub fn is_spoiler(&self) -> bool { if let TextEntityType::Spoiler(_) = self { true } else { false } }
-  pub fn is_strikethrough(&self) -> bool { if let TextEntityType::Strikethrough(_) = self { true } else { false } }
   pub fn is_text_url(&self) -> bool { if let TextEntityType::TextUrl(_) = self { true } else { false } }
-  pub fn is_underline(&self) -> bool { if let TextEntityType::Underline(_) = self { true } else { false } }
   pub fn is_url(&self) -> bool { if let TextEntityType::Url(_) = self { true } else { false } }
 
-  pub fn on_bank_card_number<F: FnOnce(&TextEntityTypeBankCardNumber)>(&self, fnc: F) -> &Self { if let TextEntityType::BankCardNumber(t) = self { fnc(t) }; self }
   pub fn on_bold<F: FnOnce(&TextEntityTypeBold)>(&self, fnc: F) -> &Self { if let TextEntityType::Bold(t) = self { fnc(t) }; self }
   pub fn on_bot_command<F: FnOnce(&TextEntityTypeBotCommand)>(&self, fnc: F) -> &Self { if let TextEntityType::BotCommand(t) = self { fnc(t) }; self }
   pub fn on_cashtag<F: FnOnce(&TextEntityTypeCashtag)>(&self, fnc: F) -> &Self { if let TextEntityType::Cashtag(t) = self { fnc(t) }; self }
@@ -179,19 +148,14 @@ impl TextEntityType {
   pub fn on_email_address<F: FnOnce(&TextEntityTypeEmailAddress)>(&self, fnc: F) -> &Self { if let TextEntityType::EmailAddress(t) = self { fnc(t) }; self }
   pub fn on_hashtag<F: FnOnce(&TextEntityTypeHashtag)>(&self, fnc: F) -> &Self { if let TextEntityType::Hashtag(t) = self { fnc(t) }; self }
   pub fn on_italic<F: FnOnce(&TextEntityTypeItalic)>(&self, fnc: F) -> &Self { if let TextEntityType::Italic(t) = self { fnc(t) }; self }
-  pub fn on_media_timestamp<F: FnOnce(&TextEntityTypeMediaTimestamp)>(&self, fnc: F) -> &Self { if let TextEntityType::MediaTimestamp(t) = self { fnc(t) }; self }
   pub fn on_mention<F: FnOnce(&TextEntityTypeMention)>(&self, fnc: F) -> &Self { if let TextEntityType::Mention(t) = self { fnc(t) }; self }
   pub fn on_mention_name<F: FnOnce(&TextEntityTypeMentionName)>(&self, fnc: F) -> &Self { if let TextEntityType::MentionName(t) = self { fnc(t) }; self }
   pub fn on_phone_number<F: FnOnce(&TextEntityTypePhoneNumber)>(&self, fnc: F) -> &Self { if let TextEntityType::PhoneNumber(t) = self { fnc(t) }; self }
   pub fn on_pre<F: FnOnce(&TextEntityTypePre)>(&self, fnc: F) -> &Self { if let TextEntityType::Pre(t) = self { fnc(t) }; self }
   pub fn on_pre_code<F: FnOnce(&TextEntityTypePreCode)>(&self, fnc: F) -> &Self { if let TextEntityType::PreCode(t) = self { fnc(t) }; self }
-  pub fn on_spoiler<F: FnOnce(&TextEntityTypeSpoiler)>(&self, fnc: F) -> &Self { if let TextEntityType::Spoiler(t) = self { fnc(t) }; self }
-  pub fn on_strikethrough<F: FnOnce(&TextEntityTypeStrikethrough)>(&self, fnc: F) -> &Self { if let TextEntityType::Strikethrough(t) = self { fnc(t) }; self }
   pub fn on_text_url<F: FnOnce(&TextEntityTypeTextUrl)>(&self, fnc: F) -> &Self { if let TextEntityType::TextUrl(t) = self { fnc(t) }; self }
-  pub fn on_underline<F: FnOnce(&TextEntityTypeUnderline)>(&self, fnc: F) -> &Self { if let TextEntityType::Underline(t) = self { fnc(t) }; self }
   pub fn on_url<F: FnOnce(&TextEntityTypeUrl)>(&self, fnc: F) -> &Self { if let TextEntityType::Url(t) = self { fnc(t) }; self }
 
-  pub fn as_bank_card_number(&self) -> Option<&TextEntityTypeBankCardNumber> { if let TextEntityType::BankCardNumber(t) = self { return Some(t) } None }
   pub fn as_bold(&self) -> Option<&TextEntityTypeBold> { if let TextEntityType::Bold(t) = self { return Some(t) } None }
   pub fn as_bot_command(&self) -> Option<&TextEntityTypeBotCommand> { if let TextEntityType::BotCommand(t) = self { return Some(t) } None }
   pub fn as_cashtag(&self) -> Option<&TextEntityTypeCashtag> { if let TextEntityType::Cashtag(t) = self { return Some(t) } None }
@@ -199,22 +163,16 @@ impl TextEntityType {
   pub fn as_email_address(&self) -> Option<&TextEntityTypeEmailAddress> { if let TextEntityType::EmailAddress(t) = self { return Some(t) } None }
   pub fn as_hashtag(&self) -> Option<&TextEntityTypeHashtag> { if let TextEntityType::Hashtag(t) = self { return Some(t) } None }
   pub fn as_italic(&self) -> Option<&TextEntityTypeItalic> { if let TextEntityType::Italic(t) = self { return Some(t) } None }
-  pub fn as_media_timestamp(&self) -> Option<&TextEntityTypeMediaTimestamp> { if let TextEntityType::MediaTimestamp(t) = self { return Some(t) } None }
   pub fn as_mention(&self) -> Option<&TextEntityTypeMention> { if let TextEntityType::Mention(t) = self { return Some(t) } None }
   pub fn as_mention_name(&self) -> Option<&TextEntityTypeMentionName> { if let TextEntityType::MentionName(t) = self { return Some(t) } None }
   pub fn as_phone_number(&self) -> Option<&TextEntityTypePhoneNumber> { if let TextEntityType::PhoneNumber(t) = self { return Some(t) } None }
   pub fn as_pre(&self) -> Option<&TextEntityTypePre> { if let TextEntityType::Pre(t) = self { return Some(t) } None }
   pub fn as_pre_code(&self) -> Option<&TextEntityTypePreCode> { if let TextEntityType::PreCode(t) = self { return Some(t) } None }
-  pub fn as_spoiler(&self) -> Option<&TextEntityTypeSpoiler> { if let TextEntityType::Spoiler(t) = self { return Some(t) } None }
-  pub fn as_strikethrough(&self) -> Option<&TextEntityTypeStrikethrough> { if let TextEntityType::Strikethrough(t) = self { return Some(t) } None }
   pub fn as_text_url(&self) -> Option<&TextEntityTypeTextUrl> { if let TextEntityType::TextUrl(t) = self { return Some(t) } None }
-  pub fn as_underline(&self) -> Option<&TextEntityTypeUnderline> { if let TextEntityType::Underline(t) = self { return Some(t) } None }
   pub fn as_url(&self) -> Option<&TextEntityTypeUrl> { if let TextEntityType::Url(t) = self { return Some(t) } None }
 
 
 
-  pub fn bank_card_number<T: AsRef<TextEntityTypeBankCardNumber>>(t: T) -> Self { TextEntityType::BankCardNumber(t.as_ref().clone()) }
-
   pub fn bold<T: AsRef<TextEntityTypeBold>>(t: T) -> Self { TextEntityType::Bold(t.as_ref().clone()) }
 
   pub fn bot_command<T: AsRef<TextEntityTypeBotCommand>>(t: T) -> Self { TextEntityType::BotCommand(t.as_ref().clone()) }
@@ -229,8 +187,6 @@ impl TextEntityType {
 
   pub fn italic<T: AsRef<TextEntityTypeItalic>>(t: T) -> Self { TextEntityType::Italic(t.as_ref().clone()) }
 
-  pub fn media_timestamp<T: AsRef<TextEntityTypeMediaTimestamp>>(t: T) -> Self { TextEntityType::MediaTimestamp(t.as_ref().clone()) }
-
   pub fn mention<T: AsRef<TextEntityTypeMention>>(t: T) -> Self { TextEntityType::Mention(t.as_ref().clone()) }
 
   pub fn mention_name<T: AsRef<TextEntityTypeMentionName>>(t: T) -> Self { TextEntityType::MentionName(t.as_ref().clone()) }
@@ -241,14 +197,8 @@ impl TextEntityType {
 
   pub fn pre_code<T: AsRef<TextEntityTypePreCode>>(t: T) -> Self { TextEntityType::PreCode(t.as_ref().clone()) }
 
-  pub fn spoiler<T: AsRef<TextEntityTypeSpoiler>>(t: T) -> Self { TextEntityType::Spoiler(t.as_ref().clone()) }
-
-  pub fn strikethrough<T: AsRef<TextEntityTypeStrikethrough>>(t: T) -> Self { TextEntityType::Strikethrough(t.as_ref().clone()) }
-
   pub fn text_url<T: AsRef<TextEntityTypeTextUrl>>(t: T) -> Self { TextEntityType::TextUrl(t.as_ref().clone()) }
 
-  pub fn underline<T: AsRef<TextEntityTypeUnderline>>(t: T) -> Self { TextEntityType::Underline(t.as_ref().clone()) }
-
   pub fn url<T: AsRef<TextEntityTypeUrl>>(t: T) -> Self { TextEntityType::Url(t.as_ref().clone()) }
 
 }
@@ -263,64 +213,6 @@ impl AsRef<TextEntityType> for TextEntityType {
 
 
 
-/// A bank card number. The getBankCardInfo method can be used to get information about the bank card
-#[derive(Debug, Clone, Default, Serialize, Deserialize)]
-pub struct TextEntityTypeBankCardNumber {
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@type", deserialize = "@type"))]
-  td_name: String,
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
-  extra: Option<String>,
-  
-}
-
-impl RObject for TextEntityTypeBankCardNumber {
-  #[doc(hidden)] fn td_name(&self) -> &'static str { "textEntityTypeBankCardNumber" }
-  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
-  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
-}
-
-
-impl TDTextEntityType for TextEntityTypeBankCardNumber {}
-
-
-
-impl TextEntityTypeBankCardNumber {
-  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
-  pub fn builder() -> RTDTextEntityTypeBankCardNumberBuilder {
-    let mut inner = TextEntityTypeBankCardNumber::default();
-    inner.td_name = "textEntityTypeBankCardNumber".to_string();
-    inner.extra = Some(Uuid::new_v4().to_string());
-    RTDTextEntityTypeBankCardNumberBuilder { inner }
-  }
-
-}
-
-#[doc(hidden)]
-pub struct RTDTextEntityTypeBankCardNumberBuilder {
-  inner: TextEntityTypeBankCardNumber
-}
-
-impl RTDTextEntityTypeBankCardNumberBuilder {
-  pub fn build(&self) -> TextEntityTypeBankCardNumber { self.inner.clone() }
-
-}
-
-impl AsRef<TextEntityTypeBankCardNumber> for TextEntityTypeBankCardNumber {
-  fn as_ref(&self) -> &TextEntityTypeBankCardNumber { self }
-}
-
-impl AsRef<TextEntityTypeBankCardNumber> for RTDTextEntityTypeBankCardNumberBuilder {
-  fn as_ref(&self) -> &TextEntityTypeBankCardNumber { &self.inner }
-}
-
-
-
-
-
-
-
 /// A bold text
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct TextEntityTypeBold {
@@ -379,7 +271,7 @@ impl AsRef<TextEntityTypeBold> for RTDTextEntityTypeBoldBuilder {
 
 
 
-/// A bot command, beginning with "/"
+/// A bot command, beginning with "/". This shouldn't be highlighted if there are no bots in the chat
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct TextEntityTypeBotCommand {
   #[doc(hidden)]
@@ -437,7 +329,7 @@ impl AsRef<TextEntityTypeBotCommand> for RTDTextEntityTypeBotCommandBuilder {
 
 
 
-/// A cashtag text, beginning with "$" and consisting of capital English letters (e.g., "$USD")
+/// A cashtag text, beginning with "$" and consisting of capital english letters (i.e. "$USD")
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct TextEntityTypeCashtag {
   #[doc(hidden)]
@@ -727,74 +619,6 @@ impl AsRef<TextEntityTypeItalic> for RTDTextEntityTypeItalicBuilder {
 
 
 
-/// A media timestamp
-#[derive(Debug, Clone, Default, Serialize, Deserialize)]
-pub struct TextEntityTypeMediaTimestamp {
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@type", deserialize = "@type"))]
-  td_name: String,
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
-  extra: Option<String>,
-  /// Timestamp from which a video/audio/video note/voice note playing must start, in seconds. The media can be in the content or the web page preview of the current message, or in the same places in the replied message
-  media_timestamp: i64,
-  
-}
-
-impl RObject for TextEntityTypeMediaTimestamp {
-  #[doc(hidden)] fn td_name(&self) -> &'static str { "textEntityTypeMediaTimestamp" }
-  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
-  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
-}
-
-
-impl TDTextEntityType for TextEntityTypeMediaTimestamp {}
-
-
-
-impl TextEntityTypeMediaTimestamp {
-  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
-  pub fn builder() -> RTDTextEntityTypeMediaTimestampBuilder {
-    let mut inner = TextEntityTypeMediaTimestamp::default();
-    inner.td_name = "textEntityTypeMediaTimestamp".to_string();
-    inner.extra = Some(Uuid::new_v4().to_string());
-    RTDTextEntityTypeMediaTimestampBuilder { inner }
-  }
-
-  pub fn media_timestamp(&self) -> i64 { self.media_timestamp }
-
-}
-
-#[doc(hidden)]
-pub struct RTDTextEntityTypeMediaTimestampBuilder {
-  inner: TextEntityTypeMediaTimestamp
-}
-
-impl RTDTextEntityTypeMediaTimestampBuilder {
-  pub fn build(&self) -> TextEntityTypeMediaTimestamp { self.inner.clone() }
-
-   
-  pub fn media_timestamp(&mut self, media_timestamp: i64) -> &mut Self {
-    self.inner.media_timestamp = media_timestamp;
-    self
-  }
-
-}
-
-impl AsRef<TextEntityTypeMediaTimestamp> for TextEntityTypeMediaTimestamp {
-  fn as_ref(&self) -> &TextEntityTypeMediaTimestamp { self }
-}
-
-impl AsRef<TextEntityTypeMediaTimestamp> for RTDTextEntityTypeMediaTimestampBuilder {
-  fn as_ref(&self) -> &TextEntityTypeMediaTimestamp { &self.inner }
-}
-
-
-
-
-
-
-
 /// A mention of a user by their username
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct TextEntityTypeMention {
@@ -1105,122 +929,6 @@ impl AsRef<TextEntityTypePreCode> for RTDTextEntityTypePreCodeBuilder {
 
 
 
-/// A spoiler text. Not supported in secret chats
-#[derive(Debug, Clone, Default, Serialize, Deserialize)]
-pub struct TextEntityTypeSpoiler {
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@type", deserialize = "@type"))]
-  td_name: String,
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
-  extra: Option<String>,
-  
-}
-
-impl RObject for TextEntityTypeSpoiler {
-  #[doc(hidden)] fn td_name(&self) -> &'static str { "textEntityTypeSpoiler" }
-  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
-  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
-}
-
-
-impl TDTextEntityType for TextEntityTypeSpoiler {}
-
-
-
-impl TextEntityTypeSpoiler {
-  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
-  pub fn builder() -> RTDTextEntityTypeSpoilerBuilder {
-    let mut inner = TextEntityTypeSpoiler::default();
-    inner.td_name = "textEntityTypeSpoiler".to_string();
-    inner.extra = Some(Uuid::new_v4().to_string());
-    RTDTextEntityTypeSpoilerBuilder { inner }
-  }
-
-}
-
-#[doc(hidden)]
-pub struct RTDTextEntityTypeSpoilerBuilder {
-  inner: TextEntityTypeSpoiler
-}
-
-impl RTDTextEntityTypeSpoilerBuilder {
-  pub fn build(&self) -> TextEntityTypeSpoiler { self.inner.clone() }
-
-}
-
-impl AsRef<TextEntityTypeSpoiler> for TextEntityTypeSpoiler {
-  fn as_ref(&self) -> &TextEntityTypeSpoiler { self }
-}
-
-impl AsRef<TextEntityTypeSpoiler> for RTDTextEntityTypeSpoilerBuilder {
-  fn as_ref(&self) -> &TextEntityTypeSpoiler { &self.inner }
-}
-
-
-
-
-
-
-
-/// A strikethrough text
-#[derive(Debug, Clone, Default, Serialize, Deserialize)]
-pub struct TextEntityTypeStrikethrough {
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@type", deserialize = "@type"))]
-  td_name: String,
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
-  extra: Option<String>,
-  
-}
-
-impl RObject for TextEntityTypeStrikethrough {
-  #[doc(hidden)] fn td_name(&self) -> &'static str { "textEntityTypeStrikethrough" }
-  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
-  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
-}
-
-
-impl TDTextEntityType for TextEntityTypeStrikethrough {}
-
-
-
-impl TextEntityTypeStrikethrough {
-  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
-  pub fn builder() -> RTDTextEntityTypeStrikethroughBuilder {
-    let mut inner = TextEntityTypeStrikethrough::default();
-    inner.td_name = "textEntityTypeStrikethrough".to_string();
-    inner.extra = Some(Uuid::new_v4().to_string());
-    RTDTextEntityTypeStrikethroughBuilder { inner }
-  }
-
-}
-
-#[doc(hidden)]
-pub struct RTDTextEntityTypeStrikethroughBuilder {
-  inner: TextEntityTypeStrikethrough
-}
-
-impl RTDTextEntityTypeStrikethroughBuilder {
-  pub fn build(&self) -> TextEntityTypeStrikethrough { self.inner.clone() }
-
-}
-
-impl AsRef<TextEntityTypeStrikethrough> for TextEntityTypeStrikethrough {
-  fn as_ref(&self) -> &TextEntityTypeStrikethrough { self }
-}
-
-impl AsRef<TextEntityTypeStrikethrough> for RTDTextEntityTypeStrikethroughBuilder {
-  fn as_ref(&self) -> &TextEntityTypeStrikethrough { &self.inner }
-}
-
-
-
-
-
-
-
 /// A text description shown instead of a raw URL
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct TextEntityTypeTextUrl {
@@ -1289,64 +997,6 @@ impl AsRef<TextEntityTypeTextUrl> for RTDTextEntityTypeTextUrlBuilder {
 
 
 
-/// An underlined text
-#[derive(Debug, Clone, Default, Serialize, Deserialize)]
-pub struct TextEntityTypeUnderline {
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@type", deserialize = "@type"))]
-  td_name: String,
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
-  extra: Option<String>,
-  
-}
-
-impl RObject for TextEntityTypeUnderline {
-  #[doc(hidden)] fn td_name(&self) -> &'static str { "textEntityTypeUnderline" }
-  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
-  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
-}
-
-
-impl TDTextEntityType for TextEntityTypeUnderline {}
-
-
-
-impl TextEntityTypeUnderline {
-  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
-  pub fn builder() -> RTDTextEntityTypeUnderlineBuilder {
-    let mut inner = TextEntityTypeUnderline::default();
-    inner.td_name = "textEntityTypeUnderline".to_string();
-    inner.extra = Some(Uuid::new_v4().to_string());
-    RTDTextEntityTypeUnderlineBuilder { inner }
-  }
-
-}
-
-#[doc(hidden)]
-pub struct RTDTextEntityTypeUnderlineBuilder {
-  inner: TextEntityTypeUnderline
-}
-
-impl RTDTextEntityTypeUnderlineBuilder {
-  pub fn build(&self) -> TextEntityTypeUnderline { self.inner.clone() }
-
-}
-
-impl AsRef<TextEntityTypeUnderline> for TextEntityTypeUnderline {
-  fn as_ref(&self) -> &TextEntityTypeUnderline { self }
-}
-
-impl AsRef<TextEntityTypeUnderline> for RTDTextEntityTypeUnderlineBuilder {
-  fn as_ref(&self) -> &TextEntityTypeUnderline { &self.inner }
-}
-
-
-
-
-
-
-
 /// An HTTP URL
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct TextEntityTypeUrl {
