@@ -11,17 +11,17 @@ use serde::de::{Deserialize, Deserializer};
 
 
 
-/// TRAIT | Describes the way the text needs to be parsed for TextEntities
+/// TRAIT | Describes the way the text should be parsed for TextEntities
 pub trait TDTextParseMode: Debug + RObject {}
 
-/// Describes the way the text needs to be parsed for TextEntities
+/// Describes the way the text should be parsed for TextEntities
 #[derive(Debug, Clone, Serialize)]
 #[serde(untagged)]
 pub enum TextParseMode {
   #[doc(hidden)] _Default(()),
-  /// The text uses HTML-style formatting. The same as Telegram Bot API "HTML" parse mode
+  /// The text should be parsed in HTML-style
   HTML(TextParseModeHTML),
-  /// The text uses Markdown-style formatting
+  /// The text should be parsed in markdown-style
   Markdown(TextParseModeMarkdown),
 
 }
@@ -93,7 +93,7 @@ impl AsRef<TextParseMode> for TextParseMode {
 
 
 
-/// The text uses HTML-style formatting. The same as Telegram Bot API "HTML" parse mode
+/// The text should be parsed in HTML-style
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct TextParseModeHTML {
   #[doc(hidden)]
@@ -151,7 +151,7 @@ impl AsRef<TextParseModeHTML> for RTDTextParseModeHTMLBuilder {
 
 
 
-/// The text uses Markdown-style formatting
+/// The text should be parsed in markdown-style
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct TextParseModeMarkdown {
   #[doc(hidden)]
@@ -160,8 +160,6 @@ pub struct TextParseModeMarkdown {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// Version of the parser: 0 or 1  Telegram Bot API "Markdown" parse mode, 2  Telegram Bot API "MarkdownV2" parse mode
-  version: i64,
   
 }
 
@@ -185,8 +183,6 @@ impl TextParseModeMarkdown {
     RTDTextParseModeMarkdownBuilder { inner }
   }
 
-  pub fn version(&self) -> i64 { self.version }
-
 }
 
 #[doc(hidden)]
@@ -197,12 +193,6 @@ pub struct RTDTextParseModeMarkdownBuilder {
 impl RTDTextParseModeMarkdownBuilder {
   pub fn build(&self) -> TextParseModeMarkdown { self.inner.clone() }
 
-   
-  pub fn version(&mut self, version: i64) -> &mut Self {
-    self.inner.version = version;
-    self
-  }
-
 }
 
 impl AsRef<TextParseModeMarkdown> for TextParseModeMarkdown {
